/********************************************************************************
** Form generated from reading UI file 'configurationDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGURATIONDIALOG_H
#define UI_CONFIGURATIONDIALOG_H

#include <Dialog.hpp>
#include <QtCore/QDate>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QCommandLinkButton>
#include <QtWidgets/QDateTimeEdit>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTimeEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/ColorButton.hpp"

QT_BEGIN_NAMESPACE

class Ui_configurationDialogForm
{
public:
    QVBoxLayout *vboxLayout;
    TitleBar *titleBar;
    QFrame *viewContent;
    QGridLayout *gridLayout;
    QListWidget *stackListWidget;
    QStackedWidget *configurationStackedWidget;
    QWidget *page_Main;
    QVBoxLayout *verticalLayout_10;
    QGroupBox *groupBox_LanguageSettings;
    QGridLayout *gridLayoutLanguageSettings;
    QGridLayout *languageGridLayout;
    QLabel *programLanguageLabel;
    QSpacerItem *horizontalSpacer_9;
    QToolButton *languageSaveToolButton;
    QComboBox *programLanguageComboBox;
    QSpacerItem *horizontalSpacer_8;
    QGroupBox *groupBox_EphemerisSettings;
    QGridLayout *gridLayoutEphemeris;
    QGridLayout *EphemerisGridLayout;
    QLabel *de431label;
    QCheckBox *de430checkBox;
    QCheckBox *de440checkBox;
    QCheckBox *de431checkBox;
    QLabel *de440label;
    QCheckBox *de441checkBox;
    QLabel *de441label;
    QLabel *de430label;
    QLabel *label_VSOP87used;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_4x;
    QHBoxLayout *horizontalLayout_3;
    QPushButton *saveViewDirAsDefaultPushButton;
    QPushButton *saveSettingsAsDefaultPushButton;
    QCheckBox *immediateSaveCheckBox;
    QPushButton *restoreDefaultsButton;
    QLabel *saveDefaultOptionsLabel;
    QHBoxLayout *horizontalLayout_2;
    QLabel *startupFOVLabel;
    QLabel *startupDirectionOfViewlabel;
    QSpacerItem *verticalSpacer_4;
    QWidget *page_Info;
    QVBoxLayout *verticalLayout_Info;
    QGroupBox *selectedInfoGroupBox;
    QGridLayout *gridLayoutSelectedObjInfo;
    QRadioButton *allSelectedInfoRadio;
    QRadioButton *defaultSelectedInfoRadio;
    QRadioButton *briefSelectedInfoRadio;
    QRadioButton *noSelectedInfoRadio;
    QRadioButton *customSelectedInfoRadio;
    QGroupBox *groupBoxDisplayedFields;
    QGridLayout *gridLayoutDisplayedFields;
    QCheckBox *checkBoxName;
    QCheckBox *checkBoxName_Narrate;
    QLabel *label_infoName;
    QCheckBox *checkBoxCatalogNumbers;
    QCheckBox *checkBoxCatalogNumbers_Narrate;
    QLabel *label_infoCat;
    QCheckBox *checkBoxRaDecJ2000;
    QCheckBox *checkBoxRaDecJ2000_Narrate;
    QLabel *label_infoRaDec2000;
    QCheckBox *checkBoxRaDecOfDate;
    QCheckBox *checkBoxRaDecOfDate_Narrate;
    QLabel *label_infoRaDec;
    QCheckBox *checkBoxHourAngle;
    QCheckBox *checkBoxHourAngle_Narrate;
    QLabel *label_infoHADec;
    QCheckBox *checkBoxAltAz;
    QCheckBox *checkBoxAltAz_Narrate;
    QLabel *label_infoAltAz;
    QCheckBox *checkBoxEclipticCoordsJ2000;
    QCheckBox *checkBoxEclipticCoordsJ2000_Narrate;
    QLabel *label_infoEcl2000;
    QCheckBox *checkBoxEclipticCoordsOfDate;
    QCheckBox *checkBoxEclipticCoordsOfDate_Narrate;
    QLabel *label_infoEcl;
    QCheckBox *checkBoxGalacticCoordinates;
    QCheckBox *checkBoxGalacticCoordinates_Narrate;
    QLabel *label_infoGalCoords;
    QCheckBox *checkBoxSupergalacticCoordinates;
    QCheckBox *checkBoxSupergalacticCoordinates_Narrate;
    QLabel *label_infoSGalCoords;
    QCheckBox *checkBoxOtherCoords;
    QCheckBox *checkBoxOtherCoords_Narrate;
    QLabel *label_infoOtherCoords;
    QCheckBox *checkBoxElongation;
    QCheckBox *checkBoxElongation_Narrate;
    QLabel *label_infoElongation;
    QSpacerItem *horizontalSpacer_info;
    QCheckBox *checkBoxVisualMag;
    QCheckBox *checkBoxVisualMag_Narrate;
    QLabel *label_infoVisualMag;
    QCheckBox *checkBoxAbsoluteMag;
    QCheckBox *checkBoxAbsoluteMag_Narrate;
    QLabel *label_infoAbsoluteMag;
    QCheckBox *checkBoxType;
    QCheckBox *checkBoxType_Narrate;
    QLabel *label_infoType;
    QCheckBox *checkBoxSize;
    QCheckBox *checkBoxSize_Narrate;
    QLabel *label_infoSize;
    QCheckBox *checkBoxVelocity;
    QCheckBox *checkBoxVelocity_Narrate;
    QLabel *label_infoVelocity;
    QCheckBox *checkBoxProperMotion;
    QCheckBox *checkBoxProperMotion_Narrate;
    QLabel *label_infoProperMotion;
    QCheckBox *checkBoxDistance;
    QCheckBox *checkBoxDistance_Narrate;
    QLabel *label_infoDistance;
    QCheckBox *checkBoxSiderealTime;
    QCheckBox *checkBoxSiderealTime_Narrate;
    QLabel *label_infoSiderealTime;
    QCheckBox *checkBoxConstellation;
    QCheckBox *checkBoxConstellation_Narrate;
    QLabel *label_infoConstellation;
    QCheckBox *checkBoxRTSTime;
    QCheckBox *checkBoxRTSTime_Narrate;
    QLabel *label_infoRTS;
    QCheckBox *checkBoxSolarLunarPosition;
    QCheckBox *checkBoxSolarLunarPosition_Narrate;
    QLabel *label_infoSolarLunarPosition;
    QCheckBox *checkBoxExtra;
    QCheckBox *checkBoxExtra_Narrate;
    QLabel *label_infoExtra;
    QSpacerItem *verticalSpacer;
    QWidget *page_Extras;
    QGridLayout *gridLayoutExtras;
    QGroupBox *contentBox;
    QHBoxLayout *horizontalLayout;
    QCommandLinkButton *getStarsButton;
    QLabel *downloadLabel;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *downloadRetryButton;
    QPushButton *downloadCancelButton;
    QSpacerItem *verticalSpacer_3;
    QGroupBox *groupBoxAdditionalSettings;
    QGridLayout *gridLayoutAdditionalSettings;
    QCheckBox *checkBoxUMShortNotationSurfaceBrightness;
    QCheckBox *checkBoxDecimalDegrees;
    QCheckBox *checkBoxUMSurfaceBrightness;
    QCheckBox *checkBoxAzimuthFromSouth;
    QCheckBox *checkBoxUseFormattingOutput;
    QCheckBox *checkBoxUseCCSDesignations;
    QCheckBox *checkBoxPolarDistance;
    QCheckBox *checkBoxNegativeHourAngles;
    QGroupBox *groupBoxAdditionalButtons;
    QGridLayout *gridLayoutAdditionalButtons;
    QCheckBox *showObsListButtonCheckBox;
    QCheckBox *showGalacticGridButtonCheckBox;
    QCheckBox *showConstellationBoundariesButtonCheckBox;
    QCheckBox *showConstellationArtsButtonCheckBox;
    QCheckBox *showICRSGridButtonCheckBox;
    QCheckBox *showEclipticGridButtonCheckBox;
    QCheckBox *showAsterismLinesButtonCheckBox;
    QCheckBox *showAsterismLabelsButtonCheckBox;
    QCheckBox *showCardinalButtonCheckBox;
    QCheckBox *showCompassButtonCheckBox;
    QCheckBox *showNebulaBgButtonCheckbox;
    QCheckBox *showFlipButtonsCheckbox;
    QCheckBox *showDSSButtonCheckbox;
    QCheckBox *showHipsButtonCheckBox;
    QCheckBox *useButtonsBackgroundCheckBox;
    QCheckBox *showNightmodeButtonCheckBox;
    QCheckBox *showGotoSelectedButtonCheckBox;
    QCheckBox *showFullscreenButtonCheckBox;
    QCheckBox *showQuitButtonCheckBox;
    QWidget *page_Time;
    QVBoxLayout *verticalLayout_6;
    QGroupBox *timeGroupBox;
    QGridLayout *gridLayoutStartup;
    QCheckBox *startupTimeStopCheckBox;
    QRadioButton *fixedTimeRadio;
    QDateTimeEdit *fixedDateTimeEdit;
    QRadioButton *todayRadio;
    QTimeEdit *todayTimeSpinBox;
    QPushButton *fixedDateTimeCurrentButton;
    QRadioButton *systemTimeRadio;
    QGroupBox *timeDisplayFormatsGroupBox;
    QGridLayout *gridLayoutFmt;
    QRadioButton *jdRadioButton;
    QComboBox *timeFormatsComboBox;
    QComboBox *dateFormatsComboBox;
    QLabel *timeFormatsLabel;
    QRadioButton *dtRadioButton;
    QGroupBox *deltaTGroupBox;
    QHBoxLayout *horizontalLayout_9;
    QFrame *frame;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_12;
    QLabel *deltaTLabel;
    QComboBox *deltaTAlgorithmComboBox;
    QToolButton *pushButtonCustomDeltaTEquationDialog;
    QSpacerItem *horizontalSpacer_2;
    QTextBrowser *deltaTAlgorithmDescription;
    QSpacerItem *verticalSpacer_5;
    QWidget *page_Tools;
    QVBoxLayout *verticalLayout_5;
    QGroupBox *planetarium_groupBox;
    QGridLayout *gridLayoutOptions;
    QHBoxLayout *mouseTimeoutLayout;
    QCheckBox *mouseTimeoutCheckbox;
    QSpacerItem *horizontalSpacer;
    QDoubleSpinBox *mouseTimeoutSpinBox;
    QCheckBox *diskViewportCheckbox;
    QCheckBox *kineticScrollingCheckBox;
    QHBoxLayout *horizontalLayout_14;
    ColorButton *daylightTextColorButton;
    QLabel *label_2;
    QCheckBox *enableMouseNavigationCheckBox;
    QGridLayout *gridLayoutInclude;
    QHBoxLayout *horizontalLayout_IncludeParallax;
    QCheckBox *parallaxCheckBox;
    QDoubleSpinBox *parallaxSpinBox;
    QHBoxLayout *horizontalLayout_IncludeNutAberr;
    QCheckBox *aberrationCheckBox;
    QDoubleSpinBox *aberrationSpinBox;
    QLabel *label_Include;
    QCheckBox *nutationCheckBox;
    QCheckBox *topocentricCheckBox;
    QHBoxLayout *horizontalLayout_fps;
    QLabel *label_fpsIntent;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_min;
    QSpinBox *minFpsSpinBox;
    QLabel *label_max;
    QSpinBox *maxFpsSpinBox;
    QHBoxLayout *horizontalLayout_keyboardNavigation;
    QCheckBox *enableKeysNavigationCheckBox;
    QSpacerItem *horizontalSpacer_3;
    QPushButton *editShortcutsPushButton;
    QHBoxLayout *horizontalLayout_dither;
    QLabel *dithering_label;
    QComboBox *ditheringComboBox;
    QCheckBox *gravityLabelCheckbox;
    QCheckBox *sphericMirrorCheckbox;
    QCheckBox *autoZoomResetsDirectionCheckbox;
    QCheckBox *focusOnDaySpinnerCheckBox;
    QCheckBox *enableMouseZoomingCheckBox;
    QCheckBox *indicationMountModeCheckBox;
    QHBoxLayout *horizontalLayout_15;
    ColorButton *overwriteTextColorButton;
    QCheckBox *overwriteTextColorCheckBox;
    QHBoxLayout *horizontalLayout_threads;
    QLabel *label_threads;
    QSpacerItem *horizontalSpacer_12;
    QSpinBox *solarSystemThreadNumberSpinBox;
    QHBoxLayout *fontHorizontalLayout;
    QLabel *fontSizeLabel;
    QSpinBox *screenFontSizeSpinBox;
    QLabel *guiFontSizeLabel;
    QSpinBox *guiFontSizeSpinBox;
    QSpacerItem *horizontalSpacer_7;
    QComboBox *fontWritingSystemComboBox;
    QFontComboBox *fontComboBox;
    QToolButton *fontSaveToolButton;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_4;
    QSpacerItem *horizontalSpacer_4;
    QDoubleSpinBox *screenButtonScaleSpinBox;
    QGroupBox *groupBox_Screenshots;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label;
    QLineEdit *screenshotDirEdit;
    QPushButton *screenshotBrowseButton;
    QPushButton *pushButtonConfigureScreenshotsDialog;
    QHBoxLayout *horizontalLayout_ScreenshotCustom;
    QLabel *labelFileFormat;
    QComboBox *screenshotFileFormatComboBox;
    QCheckBox *invertScreenShotColorsCheckBox;
    QSpacerItem *horizontalSpacer_screenshots;
    QCheckBox *useCustomScreenshotSizeCheckBox;
    QLineEdit *customScreenshotWidthLineEdit;
    QLabel *label_times;
    QLineEdit *customScreenshotHeightLineEdit;
    QLabel *label_3;
    QSpinBox *dpiSpinBox;
    QSpacerItem *verticalSpacer_2;
    QWidget *page_Speech;
    QVBoxLayout *verticalLayout_Narration;
    QGroupBox *groupBox_Narration;
    QGridLayout *gridLayoutSpeechSettings;
    QLabel *label_TestText;
    QPlainTextEdit *speechTextEdit;
    QLabel *label_engine;
    QComboBox *comboBox_Engine;
    QPushButton *pushButton_SpeechSay;
    QPushButton *pushButton_SpeechStop;
    QLabel *label_Voice;
    QComboBox *comboBox_Voice;
    QLabel *label_Pitch;
    QDoubleSpinBox *spinBox_Pitch;
    QLabel *label_Rate;
    QDoubleSpinBox *spinBox_Rate;
    QLabel *label_Volume;
    QDoubleSpinBox *spinBox_Volume;
    QWidget *page_Scripts;
    QHBoxLayout *horizontalLayout_7;
    QListWidget *scriptListWidget;
    QVBoxLayout *verticalLayout_8;
    QTextBrowser *scriptInfoBrowser;
    QGroupBox *groupBox_8;
    QVBoxLayout *verticalLayout_9;
    QLabel *scriptStatusLabel;
    QCheckBox *closeWindowAtScriptRunCheckbox;
    QHBoxLayout *horizontalLayout_4;
    QPushButton *runScriptButton;
    QPushButton *stopScriptButton;
    QWidget *page_Plugins;
    QHBoxLayout *horizontalLayout_6;
    QListWidget *pluginsListWidget;
    QVBoxLayout *pluginsVerticalLayout;
    QTextBrowser *pluginsInfoBrowser;
    QGroupBox *pluginsGroupBox;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *pluginLoadAtStartupCheckBox;
    QPushButton *pluginConfigureButton;
    QButtonGroup *buttonGroupDisplayedFields;
    QButtonGroup *buttonGroupNarrateFields;

    void setupUi(QWidget *configurationDialogForm)
    {
        if (configurationDialogForm->objectName().isEmpty())
            configurationDialogForm->setObjectName("configurationDialogForm");
        configurationDialogForm->resize(660, 575);
        vboxLayout = new QVBoxLayout(configurationDialogForm);
        vboxLayout->setSpacing(0);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        titleBar = new TitleBar(configurationDialogForm);
        titleBar->setObjectName("titleBar");

        vboxLayout->addWidget(titleBar);

        viewContent = new QFrame(configurationDialogForm);
        viewContent->setObjectName("viewContent");
        viewContent->setFrameShape(QFrame::StyledPanel);
        gridLayout = new QGridLayout(viewContent);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        stackListWidget = new QListWidget(viewContent);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/graphicGui/tabMain.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon.addFile(QString::fromUtf8(":/graphicGui/tabMain-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem->setIcon(icon);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabInfo.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon1.addFile(QString::fromUtf8(":/graphicGui/tabInfo-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem1 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem1->setIcon(icon1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabExtras.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon2.addFile(QString::fromUtf8(":/graphicGui/tabExtras-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem2 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem2->setIcon(icon2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabTime.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon3.addFile(QString::fromUtf8(":/graphicGui/tabTime-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem3 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem3->setIcon(icon3);
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabTools.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon4.addFile(QString::fromUtf8(":/graphicGui/tabTools-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem4 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem4->setIcon(icon4);
        QListWidgetItem *__qlistwidgetitem5 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem5->setIcon(icon4);
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabScripts.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon5.addFile(QString::fromUtf8(":/graphicGui/tabScripts-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem6 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem6->setIcon(icon5);
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabPlugins.png"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        icon6.addFile(QString::fromUtf8(":/graphicGui/tabPlugins-selected.png"), QSize(), QIcon::Mode::Selected, QIcon::State::On);
        QListWidgetItem *__qlistwidgetitem7 = new QListWidgetItem(stackListWidget);
        __qlistwidgetitem7->setIcon(icon6);
        stackListWidget->setObjectName("stackListWidget");
        stackListWidget->setFocusPolicy(Qt::NoFocus);
        stackListWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        stackListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
        stackListWidget->setMovement(QListView::Static);
        stackListWidget->setFlow(QListView::LeftToRight);
        stackListWidget->setProperty("isWrapping", QVariant(false));
        stackListWidget->setResizeMode(QListView::Adjust);
        stackListWidget->setLayoutMode(QListView::SinglePass);
        stackListWidget->setSpacing(0);
        stackListWidget->setViewMode(QListView::IconMode);
        stackListWidget->setUniformItemSizes(false);
        stackListWidget->setWordWrap(false);
        stackListWidget->setSelectionRectVisible(false);

        gridLayout->addWidget(stackListWidget, 0, 0, 1, 1);

        configurationStackedWidget = new QStackedWidget(viewContent);
        configurationStackedWidget->setObjectName("configurationStackedWidget");
        page_Main = new QWidget();
        page_Main->setObjectName("page_Main");
        verticalLayout_10 = new QVBoxLayout(page_Main);
        verticalLayout_10->setSpacing(0);
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        groupBox_LanguageSettings = new QGroupBox(page_Main);
        groupBox_LanguageSettings->setObjectName("groupBox_LanguageSettings");
        gridLayoutLanguageSettings = new QGridLayout(groupBox_LanguageSettings);
        gridLayoutLanguageSettings->setObjectName("gridLayoutLanguageSettings");
        gridLayoutLanguageSettings->setContentsMargins(0, 0, 0, 0);
        languageGridLayout = new QGridLayout();
        languageGridLayout->setObjectName("languageGridLayout");
        programLanguageLabel = new QLabel(groupBox_LanguageSettings);
        programLanguageLabel->setObjectName("programLanguageLabel");
        programLanguageLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        languageGridLayout->addWidget(programLanguageLabel, 0, 1, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        languageGridLayout->addItem(horizontalSpacer_9, 0, 4, 1, 1);

        languageSaveToolButton = new QToolButton(groupBox_LanguageSettings);
        languageSaveToolButton->setObjectName("languageSaveToolButton");
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/graphicGui/uibtSave.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon7.addFile(QString::fromUtf8(":/graphicGui/uibtSave-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        languageSaveToolButton->setIcon(icon7);

        languageGridLayout->addWidget(languageSaveToolButton, 0, 5, 1, 1);

        programLanguageComboBox = new QComboBox(groupBox_LanguageSettings);
        programLanguageComboBox->setObjectName("programLanguageComboBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(programLanguageComboBox->sizePolicy().hasHeightForWidth());
        programLanguageComboBox->setSizePolicy(sizePolicy);
        programLanguageComboBox->setEditable(true);
        programLanguageComboBox->setInsertPolicy(QComboBox::NoInsert);
        programLanguageComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);
        programLanguageComboBox->setFrame(true);

        languageGridLayout->addWidget(programLanguageComboBox, 0, 3, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        languageGridLayout->addItem(horizontalSpacer_8, 0, 0, 1, 1);


        gridLayoutLanguageSettings->addLayout(languageGridLayout, 0, 0, 1, 1);


        verticalLayout_10->addWidget(groupBox_LanguageSettings);

        groupBox_EphemerisSettings = new QGroupBox(page_Main);
        groupBox_EphemerisSettings->setObjectName("groupBox_EphemerisSettings");
        gridLayoutEphemeris = new QGridLayout(groupBox_EphemerisSettings);
        gridLayoutEphemeris->setObjectName("gridLayoutEphemeris");
        gridLayoutEphemeris->setContentsMargins(0, 0, 0, 0);
        EphemerisGridLayout = new QGridLayout();
        EphemerisGridLayout->setObjectName("EphemerisGridLayout");
        de431label = new QLabel(groupBox_EphemerisSettings);
        de431label->setObjectName("de431label");

        EphemerisGridLayout->addWidget(de431label, 3, 1, 1, 1);

        de430checkBox = new QCheckBox(groupBox_EphemerisSettings);
        de430checkBox->setObjectName("de430checkBox");

        EphemerisGridLayout->addWidget(de430checkBox, 2, 0, 1, 1);

        de440checkBox = new QCheckBox(groupBox_EphemerisSettings);
        de440checkBox->setObjectName("de440checkBox");

        EphemerisGridLayout->addWidget(de440checkBox, 0, 0, 1, 1);

        de431checkBox = new QCheckBox(groupBox_EphemerisSettings);
        de431checkBox->setObjectName("de431checkBox");

        EphemerisGridLayout->addWidget(de431checkBox, 3, 0, 1, 1);

        de440label = new QLabel(groupBox_EphemerisSettings);
        de440label->setObjectName("de440label");

        EphemerisGridLayout->addWidget(de440label, 0, 1, 1, 1);

        de441checkBox = new QCheckBox(groupBox_EphemerisSettings);
        de441checkBox->setObjectName("de441checkBox");

        EphemerisGridLayout->addWidget(de441checkBox, 1, 0, 1, 1);

        de441label = new QLabel(groupBox_EphemerisSettings);
        de441label->setObjectName("de441label");

        EphemerisGridLayout->addWidget(de441label, 1, 1, 1, 1);

        de430label = new QLabel(groupBox_EphemerisSettings);
        de430label->setObjectName("de430label");

        EphemerisGridLayout->addWidget(de430label, 2, 1, 1, 1);

        label_VSOP87used = new QLabel(groupBox_EphemerisSettings);
        label_VSOP87used->setObjectName("label_VSOP87used");

        EphemerisGridLayout->addWidget(label_VSOP87used, 4, 0, 1, 2);


        gridLayoutEphemeris->addLayout(EphemerisGridLayout, 0, 0, 1, 1);


        verticalLayout_10->addWidget(groupBox_EphemerisSettings);

        groupBox_6 = new QGroupBox(page_Main);
        groupBox_6->setObjectName("groupBox_6");
        verticalLayout_4x = new QVBoxLayout(groupBox_6);
        verticalLayout_4x->setObjectName("verticalLayout_4x");
        verticalLayout_4x->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        saveViewDirAsDefaultPushButton = new QPushButton(groupBox_6);
        saveViewDirAsDefaultPushButton->setObjectName("saveViewDirAsDefaultPushButton");

        horizontalLayout_3->addWidget(saveViewDirAsDefaultPushButton);

        saveSettingsAsDefaultPushButton = new QPushButton(groupBox_6);
        saveSettingsAsDefaultPushButton->setObjectName("saveSettingsAsDefaultPushButton");

        horizontalLayout_3->addWidget(saveSettingsAsDefaultPushButton);

        immediateSaveCheckBox = new QCheckBox(groupBox_6);
        immediateSaveCheckBox->setObjectName("immediateSaveCheckBox");

        horizontalLayout_3->addWidget(immediateSaveCheckBox);

        restoreDefaultsButton = new QPushButton(groupBox_6);
        restoreDefaultsButton->setObjectName("restoreDefaultsButton");

        horizontalLayout_3->addWidget(restoreDefaultsButton);


        verticalLayout_4x->addLayout(horizontalLayout_3);

        saveDefaultOptionsLabel = new QLabel(groupBox_6);
        saveDefaultOptionsLabel->setObjectName("saveDefaultOptionsLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(saveDefaultOptionsLabel->sizePolicy().hasHeightForWidth());
        saveDefaultOptionsLabel->setSizePolicy(sizePolicy1);
        saveDefaultOptionsLabel->setWordWrap(true);
        saveDefaultOptionsLabel->setTextInteractionFlags(Qt::NoTextInteraction);

        verticalLayout_4x->addWidget(saveDefaultOptionsLabel);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        startupFOVLabel = new QLabel(groupBox_6);
        startupFOVLabel->setObjectName("startupFOVLabel");
        startupFOVLabel->setText(QString::fromUtf8("Startup FOV: XX"));
        startupFOVLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(startupFOVLabel);

        startupDirectionOfViewlabel = new QLabel(groupBox_6);
        startupDirectionOfViewlabel->setObjectName("startupDirectionOfViewlabel");
        startupDirectionOfViewlabel->setText(QString::fromUtf8("Startup direction of view: xxxx"));
        startupDirectionOfViewlabel->setTextInteractionFlags(Qt::TextSelectableByMouse);

        horizontalLayout_2->addWidget(startupDirectionOfViewlabel);


        verticalLayout_4x->addLayout(horizontalLayout_2);


        verticalLayout_10->addWidget(groupBox_6);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_4);

        configurationStackedWidget->addWidget(page_Main);
        page_Info = new QWidget();
        page_Info->setObjectName("page_Info");
        verticalLayout_Info = new QVBoxLayout(page_Info);
        verticalLayout_Info->setSpacing(0);
        verticalLayout_Info->setObjectName("verticalLayout_Info");
        verticalLayout_Info->setContentsMargins(0, 0, 0, 0);
        selectedInfoGroupBox = new QGroupBox(page_Info);
        selectedInfoGroupBox->setObjectName("selectedInfoGroupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(selectedInfoGroupBox->sizePolicy().hasHeightForWidth());
        selectedInfoGroupBox->setSizePolicy(sizePolicy2);
        gridLayoutSelectedObjInfo = new QGridLayout(selectedInfoGroupBox);
        gridLayoutSelectedObjInfo->setObjectName("gridLayoutSelectedObjInfo");
        gridLayoutSelectedObjInfo->setContentsMargins(0, 0, 0, 0);
        allSelectedInfoRadio = new QRadioButton(selectedInfoGroupBox);
        allSelectedInfoRadio->setObjectName("allSelectedInfoRadio");

        gridLayoutSelectedObjInfo->addWidget(allSelectedInfoRadio, 0, 0, 1, 1);

        defaultSelectedInfoRadio = new QRadioButton(selectedInfoGroupBox);
        defaultSelectedInfoRadio->setObjectName("defaultSelectedInfoRadio");

        gridLayoutSelectedObjInfo->addWidget(defaultSelectedInfoRadio, 0, 1, 1, 1);

        briefSelectedInfoRadio = new QRadioButton(selectedInfoGroupBox);
        briefSelectedInfoRadio->setObjectName("briefSelectedInfoRadio");

        gridLayoutSelectedObjInfo->addWidget(briefSelectedInfoRadio, 0, 2, 1, 1);

        noSelectedInfoRadio = new QRadioButton(selectedInfoGroupBox);
        noSelectedInfoRadio->setObjectName("noSelectedInfoRadio");

        gridLayoutSelectedObjInfo->addWidget(noSelectedInfoRadio, 0, 3, 1, 1);

        customSelectedInfoRadio = new QRadioButton(selectedInfoGroupBox);
        customSelectedInfoRadio->setObjectName("customSelectedInfoRadio");

        gridLayoutSelectedObjInfo->addWidget(customSelectedInfoRadio, 0, 4, 1, 1);


        verticalLayout_Info->addWidget(selectedInfoGroupBox);

        groupBoxDisplayedFields = new QGroupBox(page_Info);
        groupBoxDisplayedFields->setObjectName("groupBoxDisplayedFields");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBoxDisplayedFields->sizePolicy().hasHeightForWidth());
        groupBoxDisplayedFields->setSizePolicy(sizePolicy3);
        gridLayoutDisplayedFields = new QGridLayout(groupBoxDisplayedFields);
        gridLayoutDisplayedFields->setObjectName("gridLayoutDisplayedFields");
        gridLayoutDisplayedFields->setContentsMargins(0, 0, 0, 0);
        checkBoxName = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields = new QButtonGroup(configurationDialogForm);
        buttonGroupDisplayedFields->setObjectName("buttonGroupDisplayedFields");
        buttonGroupDisplayedFields->setExclusive(false);
        buttonGroupDisplayedFields->addButton(checkBoxName);
        checkBoxName->setObjectName("checkBoxName");

        gridLayoutDisplayedFields->addWidget(checkBoxName, 0, 0, 1, 1);

        checkBoxName_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields = new QButtonGroup(configurationDialogForm);
        buttonGroupNarrateFields->setObjectName("buttonGroupNarrateFields");
        buttonGroupNarrateFields->setExclusive(false);
        buttonGroupNarrateFields->addButton(checkBoxName_Narrate);
        checkBoxName_Narrate->setObjectName("checkBoxName_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxName_Narrate, 0, 1, 1, 1);

        label_infoName = new QLabel(groupBoxDisplayedFields);
        label_infoName->setObjectName("label_infoName");

        gridLayoutDisplayedFields->addWidget(label_infoName, 0, 2, 1, 1);

        checkBoxCatalogNumbers = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxCatalogNumbers);
        checkBoxCatalogNumbers->setObjectName("checkBoxCatalogNumbers");

        gridLayoutDisplayedFields->addWidget(checkBoxCatalogNumbers, 1, 0, 1, 1);

        checkBoxCatalogNumbers_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxCatalogNumbers_Narrate);
        checkBoxCatalogNumbers_Narrate->setObjectName("checkBoxCatalogNumbers_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxCatalogNumbers_Narrate, 1, 1, 1, 1);

        label_infoCat = new QLabel(groupBoxDisplayedFields);
        label_infoCat->setObjectName("label_infoCat");

        gridLayoutDisplayedFields->addWidget(label_infoCat, 1, 2, 1, 1);

        checkBoxRaDecJ2000 = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxRaDecJ2000);
        checkBoxRaDecJ2000->setObjectName("checkBoxRaDecJ2000");

        gridLayoutDisplayedFields->addWidget(checkBoxRaDecJ2000, 2, 0, 1, 1);

        checkBoxRaDecJ2000_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxRaDecJ2000_Narrate);
        checkBoxRaDecJ2000_Narrate->setObjectName("checkBoxRaDecJ2000_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxRaDecJ2000_Narrate, 2, 1, 1, 1);

        label_infoRaDec2000 = new QLabel(groupBoxDisplayedFields);
        label_infoRaDec2000->setObjectName("label_infoRaDec2000");

        gridLayoutDisplayedFields->addWidget(label_infoRaDec2000, 2, 2, 1, 1);

        checkBoxRaDecOfDate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxRaDecOfDate);
        checkBoxRaDecOfDate->setObjectName("checkBoxRaDecOfDate");

        gridLayoutDisplayedFields->addWidget(checkBoxRaDecOfDate, 3, 0, 1, 1);

        checkBoxRaDecOfDate_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxRaDecOfDate_Narrate);
        checkBoxRaDecOfDate_Narrate->setObjectName("checkBoxRaDecOfDate_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxRaDecOfDate_Narrate, 3, 1, 1, 1);

        label_infoRaDec = new QLabel(groupBoxDisplayedFields);
        label_infoRaDec->setObjectName("label_infoRaDec");

        gridLayoutDisplayedFields->addWidget(label_infoRaDec, 3, 2, 1, 1);

        checkBoxHourAngle = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxHourAngle);
        checkBoxHourAngle->setObjectName("checkBoxHourAngle");

        gridLayoutDisplayedFields->addWidget(checkBoxHourAngle, 4, 0, 1, 1);

        checkBoxHourAngle_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxHourAngle_Narrate);
        checkBoxHourAngle_Narrate->setObjectName("checkBoxHourAngle_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxHourAngle_Narrate, 4, 1, 1, 1);

        label_infoHADec = new QLabel(groupBoxDisplayedFields);
        label_infoHADec->setObjectName("label_infoHADec");

        gridLayoutDisplayedFields->addWidget(label_infoHADec, 4, 2, 1, 1);

        checkBoxAltAz = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxAltAz);
        checkBoxAltAz->setObjectName("checkBoxAltAz");

        gridLayoutDisplayedFields->addWidget(checkBoxAltAz, 5, 0, 1, 1);

        checkBoxAltAz_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxAltAz_Narrate);
        checkBoxAltAz_Narrate->setObjectName("checkBoxAltAz_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxAltAz_Narrate, 5, 1, 1, 1);

        label_infoAltAz = new QLabel(groupBoxDisplayedFields);
        label_infoAltAz->setObjectName("label_infoAltAz");

        gridLayoutDisplayedFields->addWidget(label_infoAltAz, 5, 2, 1, 1);

        checkBoxEclipticCoordsJ2000 = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxEclipticCoordsJ2000);
        checkBoxEclipticCoordsJ2000->setObjectName("checkBoxEclipticCoordsJ2000");

        gridLayoutDisplayedFields->addWidget(checkBoxEclipticCoordsJ2000, 6, 0, 1, 1);

        checkBoxEclipticCoordsJ2000_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxEclipticCoordsJ2000_Narrate);
        checkBoxEclipticCoordsJ2000_Narrate->setObjectName("checkBoxEclipticCoordsJ2000_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxEclipticCoordsJ2000_Narrate, 6, 1, 1, 1);

        label_infoEcl2000 = new QLabel(groupBoxDisplayedFields);
        label_infoEcl2000->setObjectName("label_infoEcl2000");

        gridLayoutDisplayedFields->addWidget(label_infoEcl2000, 6, 2, 1, 1);

        checkBoxEclipticCoordsOfDate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxEclipticCoordsOfDate);
        checkBoxEclipticCoordsOfDate->setObjectName("checkBoxEclipticCoordsOfDate");

        gridLayoutDisplayedFields->addWidget(checkBoxEclipticCoordsOfDate, 7, 0, 1, 1);

        checkBoxEclipticCoordsOfDate_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxEclipticCoordsOfDate_Narrate);
        checkBoxEclipticCoordsOfDate_Narrate->setObjectName("checkBoxEclipticCoordsOfDate_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxEclipticCoordsOfDate_Narrate, 7, 1, 1, 1);

        label_infoEcl = new QLabel(groupBoxDisplayedFields);
        label_infoEcl->setObjectName("label_infoEcl");

        gridLayoutDisplayedFields->addWidget(label_infoEcl, 7, 2, 1, 1);

        checkBoxGalacticCoordinates = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxGalacticCoordinates);
        checkBoxGalacticCoordinates->setObjectName("checkBoxGalacticCoordinates");

        gridLayoutDisplayedFields->addWidget(checkBoxGalacticCoordinates, 8, 0, 1, 1);

        checkBoxGalacticCoordinates_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxGalacticCoordinates_Narrate);
        checkBoxGalacticCoordinates_Narrate->setObjectName("checkBoxGalacticCoordinates_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxGalacticCoordinates_Narrate, 8, 1, 1, 1);

        label_infoGalCoords = new QLabel(groupBoxDisplayedFields);
        label_infoGalCoords->setObjectName("label_infoGalCoords");

        gridLayoutDisplayedFields->addWidget(label_infoGalCoords, 8, 2, 1, 1);

        checkBoxSupergalacticCoordinates = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxSupergalacticCoordinates);
        checkBoxSupergalacticCoordinates->setObjectName("checkBoxSupergalacticCoordinates");

        gridLayoutDisplayedFields->addWidget(checkBoxSupergalacticCoordinates, 9, 0, 1, 1);

        checkBoxSupergalacticCoordinates_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxSupergalacticCoordinates_Narrate);
        checkBoxSupergalacticCoordinates_Narrate->setObjectName("checkBoxSupergalacticCoordinates_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxSupergalacticCoordinates_Narrate, 9, 1, 1, 1);

        label_infoSGalCoords = new QLabel(groupBoxDisplayedFields);
        label_infoSGalCoords->setObjectName("label_infoSGalCoords");

        gridLayoutDisplayedFields->addWidget(label_infoSGalCoords, 9, 2, 1, 1);

        checkBoxOtherCoords = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxOtherCoords);
        checkBoxOtherCoords->setObjectName("checkBoxOtherCoords");

        gridLayoutDisplayedFields->addWidget(checkBoxOtherCoords, 10, 0, 1, 1);

        checkBoxOtherCoords_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxOtherCoords_Narrate);
        checkBoxOtherCoords_Narrate->setObjectName("checkBoxOtherCoords_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxOtherCoords_Narrate, 10, 1, 1, 1);

        label_infoOtherCoords = new QLabel(groupBoxDisplayedFields);
        label_infoOtherCoords->setObjectName("label_infoOtherCoords");

        gridLayoutDisplayedFields->addWidget(label_infoOtherCoords, 10, 2, 1, 1);

        checkBoxElongation = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxElongation);
        checkBoxElongation->setObjectName("checkBoxElongation");

        gridLayoutDisplayedFields->addWidget(checkBoxElongation, 11, 0, 1, 1);

        checkBoxElongation_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxElongation_Narrate);
        checkBoxElongation_Narrate->setObjectName("checkBoxElongation_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxElongation_Narrate, 11, 1, 1, 1);

        label_infoElongation = new QLabel(groupBoxDisplayedFields);
        label_infoElongation->setObjectName("label_infoElongation");

        gridLayoutDisplayedFields->addWidget(label_infoElongation, 11, 2, 1, 1);

        horizontalSpacer_info = new QSpacerItem(15, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayoutDisplayedFields->addItem(horizontalSpacer_info, 0, 3, 1, 1);

        checkBoxVisualMag = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxVisualMag);
        checkBoxVisualMag->setObjectName("checkBoxVisualMag");

        gridLayoutDisplayedFields->addWidget(checkBoxVisualMag, 0, 4, 1, 1);

        checkBoxVisualMag_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxVisualMag_Narrate);
        checkBoxVisualMag_Narrate->setObjectName("checkBoxVisualMag_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxVisualMag_Narrate, 0, 5, 1, 1);

        label_infoVisualMag = new QLabel(groupBoxDisplayedFields);
        label_infoVisualMag->setObjectName("label_infoVisualMag");

        gridLayoutDisplayedFields->addWidget(label_infoVisualMag, 0, 6, 1, 1);

        checkBoxAbsoluteMag = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxAbsoluteMag);
        checkBoxAbsoluteMag->setObjectName("checkBoxAbsoluteMag");

        gridLayoutDisplayedFields->addWidget(checkBoxAbsoluteMag, 1, 4, 1, 1);

        checkBoxAbsoluteMag_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxAbsoluteMag_Narrate);
        checkBoxAbsoluteMag_Narrate->setObjectName("checkBoxAbsoluteMag_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxAbsoluteMag_Narrate, 1, 5, 1, 1);

        label_infoAbsoluteMag = new QLabel(groupBoxDisplayedFields);
        label_infoAbsoluteMag->setObjectName("label_infoAbsoluteMag");

        gridLayoutDisplayedFields->addWidget(label_infoAbsoluteMag, 1, 6, 1, 1);

        checkBoxType = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxType);
        checkBoxType->setObjectName("checkBoxType");

        gridLayoutDisplayedFields->addWidget(checkBoxType, 2, 4, 1, 1);

        checkBoxType_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxType_Narrate);
        checkBoxType_Narrate->setObjectName("checkBoxType_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxType_Narrate, 2, 5, 1, 1);

        label_infoType = new QLabel(groupBoxDisplayedFields);
        label_infoType->setObjectName("label_infoType");

        gridLayoutDisplayedFields->addWidget(label_infoType, 2, 6, 1, 1);

        checkBoxSize = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxSize);
        checkBoxSize->setObjectName("checkBoxSize");

        gridLayoutDisplayedFields->addWidget(checkBoxSize, 3, 4, 1, 1);

        checkBoxSize_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxSize_Narrate);
        checkBoxSize_Narrate->setObjectName("checkBoxSize_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxSize_Narrate, 3, 5, 1, 1);

        label_infoSize = new QLabel(groupBoxDisplayedFields);
        label_infoSize->setObjectName("label_infoSize");

        gridLayoutDisplayedFields->addWidget(label_infoSize, 3, 6, 1, 1);

        checkBoxVelocity = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxVelocity);
        checkBoxVelocity->setObjectName("checkBoxVelocity");

        gridLayoutDisplayedFields->addWidget(checkBoxVelocity, 4, 4, 1, 1);

        checkBoxVelocity_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxVelocity_Narrate);
        checkBoxVelocity_Narrate->setObjectName("checkBoxVelocity_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxVelocity_Narrate, 4, 5, 1, 1);

        label_infoVelocity = new QLabel(groupBoxDisplayedFields);
        label_infoVelocity->setObjectName("label_infoVelocity");

        gridLayoutDisplayedFields->addWidget(label_infoVelocity, 4, 6, 1, 1);

        checkBoxProperMotion = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxProperMotion);
        checkBoxProperMotion->setObjectName("checkBoxProperMotion");

        gridLayoutDisplayedFields->addWidget(checkBoxProperMotion, 5, 4, 1, 1);

        checkBoxProperMotion_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxProperMotion_Narrate);
        checkBoxProperMotion_Narrate->setObjectName("checkBoxProperMotion_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxProperMotion_Narrate, 5, 5, 1, 1);

        label_infoProperMotion = new QLabel(groupBoxDisplayedFields);
        label_infoProperMotion->setObjectName("label_infoProperMotion");

        gridLayoutDisplayedFields->addWidget(label_infoProperMotion, 5, 6, 1, 1);

        checkBoxDistance = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxDistance);
        checkBoxDistance->setObjectName("checkBoxDistance");

        gridLayoutDisplayedFields->addWidget(checkBoxDistance, 6, 4, 1, 1);

        checkBoxDistance_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxDistance_Narrate);
        checkBoxDistance_Narrate->setObjectName("checkBoxDistance_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxDistance_Narrate, 6, 5, 1, 1);

        label_infoDistance = new QLabel(groupBoxDisplayedFields);
        label_infoDistance->setObjectName("label_infoDistance");

        gridLayoutDisplayedFields->addWidget(label_infoDistance, 6, 6, 1, 1);

        checkBoxSiderealTime = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxSiderealTime);
        checkBoxSiderealTime->setObjectName("checkBoxSiderealTime");

        gridLayoutDisplayedFields->addWidget(checkBoxSiderealTime, 7, 4, 1, 1);

        checkBoxSiderealTime_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxSiderealTime_Narrate);
        checkBoxSiderealTime_Narrate->setObjectName("checkBoxSiderealTime_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxSiderealTime_Narrate, 7, 5, 1, 1);

        label_infoSiderealTime = new QLabel(groupBoxDisplayedFields);
        label_infoSiderealTime->setObjectName("label_infoSiderealTime");

        gridLayoutDisplayedFields->addWidget(label_infoSiderealTime, 7, 6, 1, 1);

        checkBoxConstellation = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxConstellation);
        checkBoxConstellation->setObjectName("checkBoxConstellation");

        gridLayoutDisplayedFields->addWidget(checkBoxConstellation, 8, 4, 1, 1);

        checkBoxConstellation_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxConstellation_Narrate);
        checkBoxConstellation_Narrate->setObjectName("checkBoxConstellation_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxConstellation_Narrate, 8, 5, 1, 1);

        label_infoConstellation = new QLabel(groupBoxDisplayedFields);
        label_infoConstellation->setObjectName("label_infoConstellation");

        gridLayoutDisplayedFields->addWidget(label_infoConstellation, 8, 6, 1, 1);

        checkBoxRTSTime = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxRTSTime);
        checkBoxRTSTime->setObjectName("checkBoxRTSTime");

        gridLayoutDisplayedFields->addWidget(checkBoxRTSTime, 9, 4, 1, 1);

        checkBoxRTSTime_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxRTSTime_Narrate);
        checkBoxRTSTime_Narrate->setObjectName("checkBoxRTSTime_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxRTSTime_Narrate, 9, 5, 1, 1);

        label_infoRTS = new QLabel(groupBoxDisplayedFields);
        label_infoRTS->setObjectName("label_infoRTS");

        gridLayoutDisplayedFields->addWidget(label_infoRTS, 9, 6, 1, 1);

        checkBoxSolarLunarPosition = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxSolarLunarPosition);
        checkBoxSolarLunarPosition->setObjectName("checkBoxSolarLunarPosition");

        gridLayoutDisplayedFields->addWidget(checkBoxSolarLunarPosition, 10, 4, 1, 1);

        checkBoxSolarLunarPosition_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxSolarLunarPosition_Narrate);
        checkBoxSolarLunarPosition_Narrate->setObjectName("checkBoxSolarLunarPosition_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxSolarLunarPosition_Narrate, 10, 5, 1, 1);

        label_infoSolarLunarPosition = new QLabel(groupBoxDisplayedFields);
        label_infoSolarLunarPosition->setObjectName("label_infoSolarLunarPosition");

        gridLayoutDisplayedFields->addWidget(label_infoSolarLunarPosition, 10, 6, 1, 1);

        checkBoxExtra = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupDisplayedFields->addButton(checkBoxExtra);
        checkBoxExtra->setObjectName("checkBoxExtra");

        gridLayoutDisplayedFields->addWidget(checkBoxExtra, 11, 4, 1, 1);

        checkBoxExtra_Narrate = new QCheckBox(groupBoxDisplayedFields);
        buttonGroupNarrateFields->addButton(checkBoxExtra_Narrate);
        checkBoxExtra_Narrate->setObjectName("checkBoxExtra_Narrate");

        gridLayoutDisplayedFields->addWidget(checkBoxExtra_Narrate, 11, 5, 1, 1);

        label_infoExtra = new QLabel(groupBoxDisplayedFields);
        label_infoExtra->setObjectName("label_infoExtra");

        gridLayoutDisplayedFields->addWidget(label_infoExtra, 11, 6, 1, 1);


        verticalLayout_Info->addWidget(groupBoxDisplayedFields);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_Info->addItem(verticalSpacer);

        configurationStackedWidget->addWidget(page_Info);
        page_Extras = new QWidget();
        page_Extras->setObjectName("page_Extras");
        gridLayoutExtras = new QGridLayout(page_Extras);
        gridLayoutExtras->setSpacing(0);
        gridLayoutExtras->setObjectName("gridLayoutExtras");
        gridLayoutExtras->setContentsMargins(0, 0, 0, 0);
        contentBox = new QGroupBox(page_Extras);
        contentBox->setObjectName("contentBox");
        horizontalLayout = new QHBoxLayout(contentBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        getStarsButton = new QCommandLinkButton(contentBox);
        getStarsButton->setObjectName("getStarsButton");
        sizePolicy1.setHeightForWidth(getStarsButton->sizePolicy().hasHeightForWidth());
        getStarsButton->setSizePolicy(sizePolicy1);
        getStarsButton->setText(QString::fromUtf8("Get catalog x of y"));
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/graphicGui/uibtDownload.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        getStarsButton->setIcon(icon8);

        horizontalLayout->addWidget(getStarsButton);

        downloadLabel = new QLabel(contentBox);
        downloadLabel->setObjectName("downloadLabel");
        downloadLabel->setText(QString::fromUtf8("xxx"));

        horizontalLayout->addWidget(downloadLabel);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_5);

        downloadRetryButton = new QPushButton(contentBox);
        downloadRetryButton->setObjectName("downloadRetryButton");

        horizontalLayout->addWidget(downloadRetryButton);

        downloadCancelButton = new QPushButton(contentBox);
        downloadCancelButton->setObjectName("downloadCancelButton");

        horizontalLayout->addWidget(downloadCancelButton);


        gridLayoutExtras->addWidget(contentBox, 2, 0, 2, 2);

        verticalSpacer_3 = new QSpacerItem(20, 93, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayoutExtras->addItem(verticalSpacer_3, 4, 0, 1, 1);

        groupBoxAdditionalSettings = new QGroupBox(page_Extras);
        groupBoxAdditionalSettings->setObjectName("groupBoxAdditionalSettings");
        gridLayoutAdditionalSettings = new QGridLayout(groupBoxAdditionalSettings);
        gridLayoutAdditionalSettings->setObjectName("gridLayoutAdditionalSettings");
        gridLayoutAdditionalSettings->setContentsMargins(0, 0, 0, 0);
        checkBoxUMShortNotationSurfaceBrightness = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxUMShortNotationSurfaceBrightness->setObjectName("checkBoxUMShortNotationSurfaceBrightness");

        gridLayoutAdditionalSettings->addWidget(checkBoxUMShortNotationSurfaceBrightness, 1, 0, 1, 1);

        checkBoxDecimalDegrees = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxDecimalDegrees->setObjectName("checkBoxDecimalDegrees");

        gridLayoutAdditionalSettings->addWidget(checkBoxDecimalDegrees, 0, 1, 1, 1);

        checkBoxUMSurfaceBrightness = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxUMSurfaceBrightness->setObjectName("checkBoxUMSurfaceBrightness");

        gridLayoutAdditionalSettings->addWidget(checkBoxUMSurfaceBrightness, 0, 0, 1, 1);

        checkBoxAzimuthFromSouth = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxAzimuthFromSouth->setObjectName("checkBoxAzimuthFromSouth");

        gridLayoutAdditionalSettings->addWidget(checkBoxAzimuthFromSouth, 1, 1, 1, 1);

        checkBoxUseFormattingOutput = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxUseFormattingOutput->setObjectName("checkBoxUseFormattingOutput");

        gridLayoutAdditionalSettings->addWidget(checkBoxUseFormattingOutput, 4, 0, 1, 1);

        checkBoxUseCCSDesignations = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxUseCCSDesignations->setObjectName("checkBoxUseCCSDesignations");

        gridLayoutAdditionalSettings->addWidget(checkBoxUseCCSDesignations, 2, 0, 1, 1);

        checkBoxPolarDistance = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxPolarDistance->setObjectName("checkBoxPolarDistance");

        gridLayoutAdditionalSettings->addWidget(checkBoxPolarDistance, 4, 1, 1, 1);

        checkBoxNegativeHourAngles = new QCheckBox(groupBoxAdditionalSettings);
        checkBoxNegativeHourAngles->setObjectName("checkBoxNegativeHourAngles");

        gridLayoutAdditionalSettings->addWidget(checkBoxNegativeHourAngles, 2, 1, 1, 1);


        gridLayoutExtras->addWidget(groupBoxAdditionalSettings, 0, 0, 1, 2);

        groupBoxAdditionalButtons = new QGroupBox(page_Extras);
        groupBoxAdditionalButtons->setObjectName("groupBoxAdditionalButtons");
        gridLayoutAdditionalButtons = new QGridLayout(groupBoxAdditionalButtons);
        gridLayoutAdditionalButtons->setObjectName("gridLayoutAdditionalButtons");
        gridLayoutAdditionalButtons->setContentsMargins(0, 0, 0, 0);
        showObsListButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showObsListButtonCheckBox->setObjectName("showObsListButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showObsListButtonCheckBox, 6, 2, 1, 1);

        showGalacticGridButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showGalacticGridButtonCheckBox->setObjectName("showGalacticGridButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showGalacticGridButtonCheckBox, 7, 0, 1, 1);

        showConstellationBoundariesButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showConstellationBoundariesButtonCheckBox->setObjectName("showConstellationBoundariesButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showConstellationBoundariesButtonCheckBox, 1, 0, 1, 1);

        showConstellationArtsButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showConstellationArtsButtonCheckBox->setObjectName("showConstellationArtsButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showConstellationArtsButtonCheckBox, 2, 0, 1, 1);

        showICRSGridButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showICRSGridButtonCheckBox->setObjectName("showICRSGridButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showICRSGridButtonCheckBox, 6, 0, 1, 1);

        showEclipticGridButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showEclipticGridButtonCheckBox->setObjectName("showEclipticGridButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showEclipticGridButtonCheckBox, 5, 0, 1, 1);

        showAsterismLinesButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showAsterismLinesButtonCheckBox->setObjectName("showAsterismLinesButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showAsterismLinesButtonCheckBox, 3, 0, 1, 1);

        showAsterismLabelsButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showAsterismLabelsButtonCheckBox->setObjectName("showAsterismLabelsButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showAsterismLabelsButtonCheckBox, 4, 0, 1, 1);

        showCardinalButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showCardinalButtonCheckBox->setObjectName("showCardinalButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showCardinalButtonCheckBox, 1, 1, 1, 1);

        showCompassButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showCompassButtonCheckBox->setObjectName("showCompassButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showCompassButtonCheckBox, 2, 1, 1, 1);

        showNebulaBgButtonCheckbox = new QCheckBox(groupBoxAdditionalButtons);
        showNebulaBgButtonCheckbox->setObjectName("showNebulaBgButtonCheckbox");

        gridLayoutAdditionalButtons->addWidget(showNebulaBgButtonCheckbox, 1, 2, 1, 1);

        showFlipButtonsCheckbox = new QCheckBox(groupBoxAdditionalButtons);
        showFlipButtonsCheckbox->setObjectName("showFlipButtonsCheckbox");

        gridLayoutAdditionalButtons->addWidget(showFlipButtonsCheckbox, 2, 2, 1, 1);

        showDSSButtonCheckbox = new QCheckBox(groupBoxAdditionalButtons);
        showDSSButtonCheckbox->setObjectName("showDSSButtonCheckbox");

        gridLayoutAdditionalButtons->addWidget(showDSSButtonCheckbox, 3, 2, 1, 1);

        showHipsButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showHipsButtonCheckBox->setObjectName("showHipsButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showHipsButtonCheckBox, 4, 2, 1, 1);

        useButtonsBackgroundCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        useButtonsBackgroundCheckBox->setObjectName("useButtonsBackgroundCheckBox");

        gridLayoutAdditionalButtons->addWidget(useButtonsBackgroundCheckBox, 5, 2, 1, 1);

        showNightmodeButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showNightmodeButtonCheckBox->setObjectName("showNightmodeButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showNightmodeButtonCheckBox, 3, 1, 1, 1);

        showGotoSelectedButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showGotoSelectedButtonCheckBox->setObjectName("showGotoSelectedButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showGotoSelectedButtonCheckBox, 4, 1, 1, 1);

        showFullscreenButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showFullscreenButtonCheckBox->setObjectName("showFullscreenButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showFullscreenButtonCheckBox, 5, 1, 1, 1);

        showQuitButtonCheckBox = new QCheckBox(groupBoxAdditionalButtons);
        showQuitButtonCheckBox->setObjectName("showQuitButtonCheckBox");

        gridLayoutAdditionalButtons->addWidget(showQuitButtonCheckBox, 6, 1, 1, 1);


        gridLayoutExtras->addWidget(groupBoxAdditionalButtons, 1, 0, 1, 2);

        configurationStackedWidget->addWidget(page_Extras);
        page_Time = new QWidget();
        page_Time->setObjectName("page_Time");
        verticalLayout_6 = new QVBoxLayout(page_Time);
        verticalLayout_6->setSpacing(0);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        timeGroupBox = new QGroupBox(page_Time);
        timeGroupBox->setObjectName("timeGroupBox");
        gridLayoutStartup = new QGridLayout(timeGroupBox);
        gridLayoutStartup->setObjectName("gridLayoutStartup");
        gridLayoutStartup->setContentsMargins(0, 0, 0, 0);
        startupTimeStopCheckBox = new QCheckBox(timeGroupBox);
        startupTimeStopCheckBox->setObjectName("startupTimeStopCheckBox");

        gridLayoutStartup->addWidget(startupTimeStopCheckBox, 3, 0, 1, 1);

        fixedTimeRadio = new QRadioButton(timeGroupBox);
        fixedTimeRadio->setObjectName("fixedTimeRadio");

        gridLayoutStartup->addWidget(fixedTimeRadio, 2, 0, 1, 1);

        fixedDateTimeEdit = new QDateTimeEdit(timeGroupBox);
        fixedDateTimeEdit->setObjectName("fixedDateTimeEdit");
        fixedDateTimeEdit->setDate(QDate(1952, 5, 11));
        fixedDateTimeEdit->setTime(QTime(0, 42, 0));
        fixedDateTimeEdit->setCalendarPopup(true);

        gridLayoutStartup->addWidget(fixedDateTimeEdit, 2, 1, 1, 1);

        todayRadio = new QRadioButton(timeGroupBox);
        todayRadio->setObjectName("todayRadio");

        gridLayoutStartup->addWidget(todayRadio, 0, 2, 1, 1);

        todayTimeSpinBox = new QTimeEdit(timeGroupBox);
        todayTimeSpinBox->setObjectName("todayTimeSpinBox");
        sizePolicy.setHeightForWidth(todayTimeSpinBox->sizePolicy().hasHeightForWidth());
        todayTimeSpinBox->setSizePolicy(sizePolicy);
        QFont font;
        todayTimeSpinBox->setFont(font);
        todayTimeSpinBox->setFrame(true);
        todayTimeSpinBox->setAlignment(Qt::AlignCenter);
        todayTimeSpinBox->setCurrentSectionIndex(0);
        todayTimeSpinBox->setTime(QTime(21, 0, 0));

        gridLayoutStartup->addWidget(todayTimeSpinBox, 0, 3, 1, 1);

        fixedDateTimeCurrentButton = new QPushButton(timeGroupBox);
        fixedDateTimeCurrentButton->setObjectName("fixedDateTimeCurrentButton");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(fixedDateTimeCurrentButton->sizePolicy().hasHeightForWidth());
        fixedDateTimeCurrentButton->setSizePolicy(sizePolicy4);

        gridLayoutStartup->addWidget(fixedDateTimeCurrentButton, 2, 2, 1, 2);

        systemTimeRadio = new QRadioButton(timeGroupBox);
        systemTimeRadio->setObjectName("systemTimeRadio");

        gridLayoutStartup->addWidget(systemTimeRadio, 0, 0, 1, 2);


        verticalLayout_6->addWidget(timeGroupBox);

        timeDisplayFormatsGroupBox = new QGroupBox(page_Time);
        timeDisplayFormatsGroupBox->setObjectName("timeDisplayFormatsGroupBox");
        gridLayoutFmt = new QGridLayout(timeDisplayFormatsGroupBox);
        gridLayoutFmt->setObjectName("gridLayoutFmt");
        gridLayoutFmt->setContentsMargins(0, 0, 0, 0);
        jdRadioButton = new QRadioButton(timeDisplayFormatsGroupBox);
        jdRadioButton->setObjectName("jdRadioButton");
        jdRadioButton->setText(QString::fromUtf8("JD"));

        gridLayoutFmt->addWidget(jdRadioButton, 0, 0, 1, 1);

        timeFormatsComboBox = new QComboBox(timeDisplayFormatsGroupBox);
        timeFormatsComboBox->setObjectName("timeFormatsComboBox");

        gridLayoutFmt->addWidget(timeFormatsComboBox, 0, 4, 1, 1);

        dateFormatsComboBox = new QComboBox(timeDisplayFormatsGroupBox);
        dateFormatsComboBox->setObjectName("dateFormatsComboBox");

        gridLayoutFmt->addWidget(dateFormatsComboBox, 0, 2, 1, 1);

        timeFormatsLabel = new QLabel(timeDisplayFormatsGroupBox);
        timeFormatsLabel->setObjectName("timeFormatsLabel");
        timeFormatsLabel->setAlignment(Qt::AlignCenter);

        gridLayoutFmt->addWidget(timeFormatsLabel, 0, 3, 1, 1);

        dtRadioButton = new QRadioButton(timeDisplayFormatsGroupBox);
        dtRadioButton->setObjectName("dtRadioButton");
        sizePolicy4.setHeightForWidth(dtRadioButton->sizePolicy().hasHeightForWidth());
        dtRadioButton->setSizePolicy(sizePolicy4);
        dtRadioButton->setChecked(true);

        gridLayoutFmt->addWidget(dtRadioButton, 0, 1, 1, 1);


        verticalLayout_6->addWidget(timeDisplayFormatsGroupBox);

        deltaTGroupBox = new QGroupBox(page_Time);
        deltaTGroupBox->setObjectName("deltaTGroupBox");
        horizontalLayout_9 = new QHBoxLayout(deltaTGroupBox);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(0, 0, 0, 0);
        frame = new QFrame(deltaTGroupBox);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout = new QVBoxLayout(frame);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalLayout_12->setContentsMargins(6, -1, -1, -1);
        deltaTLabel = new QLabel(frame);
        deltaTLabel->setObjectName("deltaTLabel");

        horizontalLayout_12->addWidget(deltaTLabel);

        deltaTAlgorithmComboBox = new QComboBox(frame);
        deltaTAlgorithmComboBox->setObjectName("deltaTAlgorithmComboBox");
        deltaTAlgorithmComboBox->setEditable(true);
        deltaTAlgorithmComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_12->addWidget(deltaTAlgorithmComboBox);

        pushButtonCustomDeltaTEquationDialog = new QToolButton(frame);
        pushButtonCustomDeltaTEquationDialog->setObjectName("pushButtonCustomDeltaTEquationDialog");
        pushButtonCustomDeltaTEquationDialog->setEnabled(false);
        QIcon icon9;
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtSettings.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon9.addFile(QString::fromUtf8(":/graphicGui/uibtSettings-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButtonCustomDeltaTEquationDialog->setIcon(icon9);

        horizontalLayout_12->addWidget(pushButtonCustomDeltaTEquationDialog);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_12);

        deltaTAlgorithmDescription = new QTextBrowser(frame);
        deltaTAlgorithmDescription->setObjectName("deltaTAlgorithmDescription");
        deltaTAlgorithmDescription->setAutoFillBackground(true);
        deltaTAlgorithmDescription->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        deltaTAlgorithmDescription->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        deltaTAlgorithmDescription->setOpenExternalLinks(true);
        deltaTAlgorithmDescription->setOpenLinks(true);

        verticalLayout->addWidget(deltaTAlgorithmDescription);


        horizontalLayout_9->addWidget(frame);


        verticalLayout_6->addWidget(deltaTGroupBox);

        verticalSpacer_5 = new QSpacerItem(20, 66, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer_5);

        configurationStackedWidget->addWidget(page_Time);
        page_Tools = new QWidget();
        page_Tools->setObjectName("page_Tools");
        verticalLayout_5 = new QVBoxLayout(page_Tools);
        verticalLayout_5->setSpacing(0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        planetarium_groupBox = new QGroupBox(page_Tools);
        planetarium_groupBox->setObjectName("planetarium_groupBox");
        sizePolicy3.setHeightForWidth(planetarium_groupBox->sizePolicy().hasHeightForWidth());
        planetarium_groupBox->setSizePolicy(sizePolicy3);
        gridLayoutOptions = new QGridLayout(planetarium_groupBox);
        gridLayoutOptions->setObjectName("gridLayoutOptions");
        gridLayoutOptions->setContentsMargins(0, 0, 0, 0);
        mouseTimeoutLayout = new QHBoxLayout();
        mouseTimeoutLayout->setObjectName("mouseTimeoutLayout");
        mouseTimeoutCheckbox = new QCheckBox(planetarium_groupBox);
        mouseTimeoutCheckbox->setObjectName("mouseTimeoutCheckbox");

        mouseTimeoutLayout->addWidget(mouseTimeoutCheckbox);

        horizontalSpacer = new QSpacerItem(30, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        mouseTimeoutLayout->addItem(horizontalSpacer);

        mouseTimeoutSpinBox = new QDoubleSpinBox(planetarium_groupBox);
        mouseTimeoutSpinBox->setObjectName("mouseTimeoutSpinBox");
        mouseTimeoutSpinBox->setKeyboardTracking(false);
        mouseTimeoutSpinBox->setDecimals(1);
        mouseTimeoutSpinBox->setMinimum(0.000000000000000);
        mouseTimeoutSpinBox->setMaximum(3600.000000000000000);
        mouseTimeoutSpinBox->setValue(10.000000000000000);

        mouseTimeoutLayout->addWidget(mouseTimeoutSpinBox);


        gridLayoutOptions->addLayout(mouseTimeoutLayout, 7, 1, 1, 1);

        diskViewportCheckbox = new QCheckBox(planetarium_groupBox);
        diskViewportCheckbox->setObjectName("diskViewportCheckbox");

        gridLayoutOptions->addWidget(diskViewportCheckbox, 1, 1, 1, 1);

        kineticScrollingCheckBox = new QCheckBox(planetarium_groupBox);
        kineticScrollingCheckBox->setObjectName("kineticScrollingCheckBox");

        gridLayoutOptions->addWidget(kineticScrollingCheckBox, 6, 3, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        daylightTextColorButton = new ColorButton(planetarium_groupBox);
        daylightTextColorButton->setObjectName("daylightTextColorButton");

        horizontalLayout_14->addWidget(daylightTextColorButton);

        label_2 = new QLabel(planetarium_groupBox);
        label_2->setObjectName("label_2");

        horizontalLayout_14->addWidget(label_2);


        gridLayoutOptions->addLayout(horizontalLayout_14, 9, 3, 1, 1);

        enableMouseNavigationCheckBox = new QCheckBox(planetarium_groupBox);
        enableMouseNavigationCheckBox->setObjectName("enableMouseNavigationCheckBox");

        gridLayoutOptions->addWidget(enableMouseNavigationCheckBox, 5, 1, 1, 1);

        gridLayoutInclude = new QGridLayout();
        gridLayoutInclude->setObjectName("gridLayoutInclude");
        horizontalLayout_IncludeParallax = new QHBoxLayout();
        horizontalLayout_IncludeParallax->setObjectName("horizontalLayout_IncludeParallax");
        parallaxCheckBox = new QCheckBox(planetarium_groupBox);
        parallaxCheckBox->setObjectName("parallaxCheckBox");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(parallaxCheckBox->sizePolicy().hasHeightForWidth());
        parallaxCheckBox->setSizePolicy(sizePolicy5);

        horizontalLayout_IncludeParallax->addWidget(parallaxCheckBox);

        parallaxSpinBox = new QDoubleSpinBox(planetarium_groupBox);
        parallaxSpinBox->setObjectName("parallaxSpinBox");
        parallaxSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        parallaxSpinBox->setDecimals(0);
        parallaxSpinBox->setMinimum(1.000000000000000);
        parallaxSpinBox->setMaximum(100000.000000000000000);
        parallaxSpinBox->setSingleStep(100.000000000000000);
        parallaxSpinBox->setValue(1.000000000000000);

        horizontalLayout_IncludeParallax->addWidget(parallaxSpinBox);


        gridLayoutInclude->addLayout(horizontalLayout_IncludeParallax, 2, 1, 1, 1);

        horizontalLayout_IncludeNutAberr = new QHBoxLayout();
        horizontalLayout_IncludeNutAberr->setObjectName("horizontalLayout_IncludeNutAberr");
        aberrationCheckBox = new QCheckBox(planetarium_groupBox);
        aberrationCheckBox->setObjectName("aberrationCheckBox");
        sizePolicy5.setHeightForWidth(aberrationCheckBox->sizePolicy().hasHeightForWidth());
        aberrationCheckBox->setSizePolicy(sizePolicy5);

        horizontalLayout_IncludeNutAberr->addWidget(aberrationCheckBox);

        aberrationSpinBox = new QDoubleSpinBox(planetarium_groupBox);
        aberrationSpinBox->setObjectName("aberrationSpinBox");
        aberrationSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        aberrationSpinBox->setDecimals(1);
        aberrationSpinBox->setMaximum(5.000000000000000);
        aberrationSpinBox->setSingleStep(0.100000000000000);
        aberrationSpinBox->setValue(1.000000000000000);

        horizontalLayout_IncludeNutAberr->addWidget(aberrationSpinBox);


        gridLayoutInclude->addLayout(horizontalLayout_IncludeNutAberr, 2, 2, 1, 1);

        label_Include = new QLabel(planetarium_groupBox);
        label_Include->setObjectName("label_Include");

        gridLayoutInclude->addWidget(label_Include, 1, 0, 1, 1);

        nutationCheckBox = new QCheckBox(planetarium_groupBox);
        nutationCheckBox->setObjectName("nutationCheckBox");

        gridLayoutInclude->addWidget(nutationCheckBox, 1, 2, 1, 1);

        topocentricCheckBox = new QCheckBox(planetarium_groupBox);
        topocentricCheckBox->setObjectName("topocentricCheckBox");

        gridLayoutInclude->addWidget(topocentricCheckBox, 1, 1, 1, 1);


        gridLayoutOptions->addLayout(gridLayoutInclude, 0, 3, 2, 1);

        horizontalLayout_fps = new QHBoxLayout();
        horizontalLayout_fps->setObjectName("horizontalLayout_fps");
        label_fpsIntent = new QLabel(planetarium_groupBox);
        label_fpsIntent->setObjectName("label_fpsIntent");

        horizontalLayout_fps->addWidget(label_fpsIntent);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_fps->addItem(horizontalSpacer_6);

        label_min = new QLabel(planetarium_groupBox);
        label_min->setObjectName("label_min");

        horizontalLayout_fps->addWidget(label_min);

        minFpsSpinBox = new QSpinBox(planetarium_groupBox);
        minFpsSpinBox->setObjectName("minFpsSpinBox");
        minFpsSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        minFpsSpinBox->setKeyboardTracking(false);
        minFpsSpinBox->setMinimum(1);
        minFpsSpinBox->setMaximum(1000);

        horizontalLayout_fps->addWidget(minFpsSpinBox);

        label_max = new QLabel(planetarium_groupBox);
        label_max->setObjectName("label_max");

        horizontalLayout_fps->addWidget(label_max);

        maxFpsSpinBox = new QSpinBox(planetarium_groupBox);
        maxFpsSpinBox->setObjectName("maxFpsSpinBox");
        maxFpsSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        maxFpsSpinBox->setKeyboardTracking(false);
        maxFpsSpinBox->setMinimum(5);
        maxFpsSpinBox->setMaximum(1000);
        maxFpsSpinBox->setValue(1000);

        horizontalLayout_fps->addWidget(maxFpsSpinBox);


        gridLayoutOptions->addLayout(horizontalLayout_fps, 3, 3, 1, 1);

        horizontalLayout_keyboardNavigation = new QHBoxLayout();
        horizontalLayout_keyboardNavigation->setObjectName("horizontalLayout_keyboardNavigation");
        enableKeysNavigationCheckBox = new QCheckBox(planetarium_groupBox);
        enableKeysNavigationCheckBox->setObjectName("enableKeysNavigationCheckBox");

        horizontalLayout_keyboardNavigation->addWidget(enableKeysNavigationCheckBox);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_keyboardNavigation->addItem(horizontalSpacer_3);

        editShortcutsPushButton = new QPushButton(planetarium_groupBox);
        editShortcutsPushButton->setObjectName("editShortcutsPushButton");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(editShortcutsPushButton->sizePolicy().hasHeightForWidth());
        editShortcutsPushButton->setSizePolicy(sizePolicy6);
        editShortcutsPushButton->setIcon(icon9);

        horizontalLayout_keyboardNavigation->addWidget(editShortcutsPushButton);


        gridLayoutOptions->addLayout(horizontalLayout_keyboardNavigation, 4, 1, 1, 1);

        horizontalLayout_dither = new QHBoxLayout();
        horizontalLayout_dither->setObjectName("horizontalLayout_dither");
        dithering_label = new QLabel(planetarium_groupBox);
        dithering_label->setObjectName("dithering_label");

        horizontalLayout_dither->addWidget(dithering_label);

        ditheringComboBox = new QComboBox(planetarium_groupBox);
        ditheringComboBox->setObjectName("ditheringComboBox");

        horizontalLayout_dither->addWidget(ditheringComboBox);


        gridLayoutOptions->addLayout(horizontalLayout_dither, 7, 3, 1, 1);

        gravityLabelCheckbox = new QCheckBox(planetarium_groupBox);
        gravityLabelCheckbox->setObjectName("gravityLabelCheckbox");

        gridLayoutOptions->addWidget(gravityLabelCheckbox, 2, 1, 1, 1);

        sphericMirrorCheckbox = new QCheckBox(planetarium_groupBox);
        sphericMirrorCheckbox->setObjectName("sphericMirrorCheckbox");
        sphericMirrorCheckbox->setCheckable(true);

        gridLayoutOptions->addWidget(sphericMirrorCheckbox, 0, 1, 1, 1);

        autoZoomResetsDirectionCheckbox = new QCheckBox(planetarium_groupBox);
        autoZoomResetsDirectionCheckbox->setObjectName("autoZoomResetsDirectionCheckbox");

        gridLayoutOptions->addWidget(autoZoomResetsDirectionCheckbox, 3, 1, 1, 1);

        focusOnDaySpinnerCheckBox = new QCheckBox(planetarium_groupBox);
        focusOnDaySpinnerCheckBox->setObjectName("focusOnDaySpinnerCheckBox");

        gridLayoutOptions->addWidget(focusOnDaySpinnerCheckBox, 5, 3, 1, 1);

        enableMouseZoomingCheckBox = new QCheckBox(planetarium_groupBox);
        enableMouseZoomingCheckBox->setObjectName("enableMouseZoomingCheckBox");

        gridLayoutOptions->addWidget(enableMouseZoomingCheckBox, 6, 1, 1, 1);

        indicationMountModeCheckBox = new QCheckBox(planetarium_groupBox);
        indicationMountModeCheckBox->setObjectName("indicationMountModeCheckBox");

        gridLayoutOptions->addWidget(indicationMountModeCheckBox, 2, 3, 1, 1);

        horizontalLayout_15 = new QHBoxLayout();
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        overwriteTextColorButton = new ColorButton(planetarium_groupBox);
        overwriteTextColorButton->setObjectName("overwriteTextColorButton");

        horizontalLayout_15->addWidget(overwriteTextColorButton);

        overwriteTextColorCheckBox = new QCheckBox(planetarium_groupBox);
        overwriteTextColorCheckBox->setObjectName("overwriteTextColorCheckBox");

        horizontalLayout_15->addWidget(overwriteTextColorCheckBox);


        gridLayoutOptions->addLayout(horizontalLayout_15, 9, 1, 1, 1);

        horizontalLayout_threads = new QHBoxLayout();
        horizontalLayout_threads->setObjectName("horizontalLayout_threads");
        label_threads = new QLabel(planetarium_groupBox);
        label_threads->setObjectName("label_threads");

        horizontalLayout_threads->addWidget(label_threads);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_threads->addItem(horizontalSpacer_12);

        solarSystemThreadNumberSpinBox = new QSpinBox(planetarium_groupBox);
        solarSystemThreadNumberSpinBox->setObjectName("solarSystemThreadNumberSpinBox");
        solarSystemThreadNumberSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        solarSystemThreadNumberSpinBox->setMaximum(31);

        horizontalLayout_threads->addWidget(solarSystemThreadNumberSpinBox);


        gridLayoutOptions->addLayout(horizontalLayout_threads, 4, 3, 1, 1);

        fontHorizontalLayout = new QHBoxLayout();
        fontHorizontalLayout->setObjectName("fontHorizontalLayout");
        fontSizeLabel = new QLabel(planetarium_groupBox);
        fontSizeLabel->setObjectName("fontSizeLabel");

        fontHorizontalLayout->addWidget(fontSizeLabel);

        screenFontSizeSpinBox = new QSpinBox(planetarium_groupBox);
        screenFontSizeSpinBox->setObjectName("screenFontSizeSpinBox");
        screenFontSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        screenFontSizeSpinBox->setMinimum(5);
        screenFontSizeSpinBox->setMaximum(50);
        screenFontSizeSpinBox->setValue(13);

        fontHorizontalLayout->addWidget(screenFontSizeSpinBox);

        guiFontSizeLabel = new QLabel(planetarium_groupBox);
        guiFontSizeLabel->setObjectName("guiFontSizeLabel");

        fontHorizontalLayout->addWidget(guiFontSizeLabel);

        guiFontSizeSpinBox = new QSpinBox(planetarium_groupBox);
        guiFontSizeSpinBox->setObjectName("guiFontSizeSpinBox");
        guiFontSizeSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        guiFontSizeSpinBox->setMinimum(7);
        guiFontSizeSpinBox->setMaximum(50);
        guiFontSizeSpinBox->setValue(13);

        fontHorizontalLayout->addWidget(guiFontSizeSpinBox);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        fontHorizontalLayout->addItem(horizontalSpacer_7);

        fontWritingSystemComboBox = new QComboBox(planetarium_groupBox);
        fontWritingSystemComboBox->setObjectName("fontWritingSystemComboBox");
        fontWritingSystemComboBox->setEditable(true);
        fontWritingSystemComboBox->setInsertPolicy(QComboBox::NoInsert);

        fontHorizontalLayout->addWidget(fontWritingSystemComboBox);

        fontComboBox = new QFontComboBox(planetarium_groupBox);
        fontComboBox->setObjectName("fontComboBox");

        fontHorizontalLayout->addWidget(fontComboBox);

        fontSaveToolButton = new QToolButton(planetarium_groupBox);
        fontSaveToolButton->setObjectName("fontSaveToolButton");
        fontSaveToolButton->setIcon(icon7);

        fontHorizontalLayout->addWidget(fontSaveToolButton);


        gridLayoutOptions->addLayout(fontHorizontalLayout, 10, 1, 1, 3);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_4 = new QLabel(planetarium_groupBox);
        label_4->setObjectName("label_4");

        horizontalLayout_11->addWidget(label_4);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_4);

        screenButtonScaleSpinBox = new QDoubleSpinBox(planetarium_groupBox);
        screenButtonScaleSpinBox->setObjectName("screenButtonScaleSpinBox");
        screenButtonScaleSpinBox->setSuffix(QString::fromUtf8("%"));
        screenButtonScaleSpinBox->setDecimals(0);
        screenButtonScaleSpinBox->setMinimum(10.000000000000000);
        screenButtonScaleSpinBox->setMaximum(500.000000000000000);
        screenButtonScaleSpinBox->setValue(100.000000000000000);

        horizontalLayout_11->addWidget(screenButtonScaleSpinBox);


        gridLayoutOptions->addLayout(horizontalLayout_11, 11, 1, 1, 1);


        verticalLayout_5->addWidget(planetarium_groupBox);

        groupBox_Screenshots = new QGroupBox(page_Tools);
        groupBox_Screenshots->setObjectName("groupBox_Screenshots");
        verticalLayout_3 = new QVBoxLayout(groupBox_Screenshots);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label = new QLabel(groupBox_Screenshots);
        label->setObjectName("label");

        horizontalLayout_5->addWidget(label);

        screenshotDirEdit = new QLineEdit(groupBox_Screenshots);
        screenshotDirEdit->setObjectName("screenshotDirEdit");

        horizontalLayout_5->addWidget(screenshotDirEdit);

        screenshotBrowseButton = new QPushButton(groupBox_Screenshots);
        screenshotBrowseButton->setObjectName("screenshotBrowseButton");
        sizePolicy6.setHeightForWidth(screenshotBrowseButton->sizePolicy().hasHeightForWidth());
        screenshotBrowseButton->setSizePolicy(sizePolicy6);
        QIcon icon10;
        icon10.addFile(QString::fromUtf8(":/graphicGui/uibtFolder.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon10.addFile(QString::fromUtf8(":/graphicGui/uibtFolder-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        screenshotBrowseButton->setIcon(icon10);

        horizontalLayout_5->addWidget(screenshotBrowseButton);

        pushButtonConfigureScreenshotsDialog = new QPushButton(groupBox_Screenshots);
        pushButtonConfigureScreenshotsDialog->setObjectName("pushButtonConfigureScreenshotsDialog");
        pushButtonConfigureScreenshotsDialog->setIcon(icon9);

        horizontalLayout_5->addWidget(pushButtonConfigureScreenshotsDialog);


        verticalLayout_3->addLayout(horizontalLayout_5);

        horizontalLayout_ScreenshotCustom = new QHBoxLayout();
        horizontalLayout_ScreenshotCustom->setObjectName("horizontalLayout_ScreenshotCustom");
        horizontalLayout_ScreenshotCustom->setContentsMargins(-1, 0, -1, -1);
        labelFileFormat = new QLabel(groupBox_Screenshots);
        labelFileFormat->setObjectName("labelFileFormat");

        horizontalLayout_ScreenshotCustom->addWidget(labelFileFormat);

        screenshotFileFormatComboBox = new QComboBox(groupBox_Screenshots);
        screenshotFileFormatComboBox->setObjectName("screenshotFileFormatComboBox");
        screenshotFileFormatComboBox->setEditable(true);
        screenshotFileFormatComboBox->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout_ScreenshotCustom->addWidget(screenshotFileFormatComboBox);

        invertScreenShotColorsCheckBox = new QCheckBox(groupBox_Screenshots);
        invertScreenShotColorsCheckBox->setObjectName("invertScreenShotColorsCheckBox");
        sizePolicy6.setHeightForWidth(invertScreenShotColorsCheckBox->sizePolicy().hasHeightForWidth());
        invertScreenShotColorsCheckBox->setSizePolicy(sizePolicy6);

        horizontalLayout_ScreenshotCustom->addWidget(invertScreenShotColorsCheckBox);

        horizontalSpacer_screenshots = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_ScreenshotCustom->addItem(horizontalSpacer_screenshots);

        useCustomScreenshotSizeCheckBox = new QCheckBox(groupBox_Screenshots);
        useCustomScreenshotSizeCheckBox->setObjectName("useCustomScreenshotSizeCheckBox");
        sizePolicy6.setHeightForWidth(useCustomScreenshotSizeCheckBox->sizePolicy().hasHeightForWidth());
        useCustomScreenshotSizeCheckBox->setSizePolicy(sizePolicy6);

        horizontalLayout_ScreenshotCustom->addWidget(useCustomScreenshotSizeCheckBox);

        customScreenshotWidthLineEdit = new QLineEdit(groupBox_Screenshots);
        customScreenshotWidthLineEdit->setObjectName("customScreenshotWidthLineEdit");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(customScreenshotWidthLineEdit->sizePolicy().hasHeightForWidth());
        customScreenshotWidthLineEdit->setSizePolicy(sizePolicy7);

        horizontalLayout_ScreenshotCustom->addWidget(customScreenshotWidthLineEdit);

        label_times = new QLabel(groupBox_Screenshots);
        label_times->setObjectName("label_times");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(label_times->sizePolicy().hasHeightForWidth());
        label_times->setSizePolicy(sizePolicy8);
#if QT_CONFIG(tooltip)
        label_times->setToolTip(QString::fromUtf8(""));
#endif // QT_CONFIG(tooltip)
        label_times->setText(QString::fromUtf8("x"));

        horizontalLayout_ScreenshotCustom->addWidget(label_times);

        customScreenshotHeightLineEdit = new QLineEdit(groupBox_Screenshots);
        customScreenshotHeightLineEdit->setObjectName("customScreenshotHeightLineEdit");
        sizePolicy7.setHeightForWidth(customScreenshotHeightLineEdit->sizePolicy().hasHeightForWidth());
        customScreenshotHeightLineEdit->setSizePolicy(sizePolicy7);

        horizontalLayout_ScreenshotCustom->addWidget(customScreenshotHeightLineEdit);

        label_3 = new QLabel(groupBox_Screenshots);
        label_3->setObjectName("label_3");

        horizontalLayout_ScreenshotCustom->addWidget(label_3);

        dpiSpinBox = new QSpinBox(groupBox_Screenshots);
        dpiSpinBox->setObjectName("dpiSpinBox");
        dpiSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        dpiSpinBox->setMinimum(50);
        dpiSpinBox->setMaximum(6000);
        dpiSpinBox->setValue(72);

        horizontalLayout_ScreenshotCustom->addWidget(dpiSpinBox);


        verticalLayout_3->addLayout(horizontalLayout_ScreenshotCustom);


        verticalLayout_5->addWidget(groupBox_Screenshots);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_2);

        configurationStackedWidget->addWidget(page_Tools);
        page_Speech = new QWidget();
        page_Speech->setObjectName("page_Speech");
        verticalLayout_Narration = new QVBoxLayout(page_Speech);
        verticalLayout_Narration->setSpacing(0);
        verticalLayout_Narration->setObjectName("verticalLayout_Narration");
        verticalLayout_Narration->setContentsMargins(0, 0, 0, 0);
        groupBox_Narration = new QGroupBox(page_Speech);
        groupBox_Narration->setObjectName("groupBox_Narration");
        sizePolicy2.setHeightForWidth(groupBox_Narration->sizePolicy().hasHeightForWidth());
        groupBox_Narration->setSizePolicy(sizePolicy2);
        gridLayoutSpeechSettings = new QGridLayout(groupBox_Narration);
        gridLayoutSpeechSettings->setObjectName("gridLayoutSpeechSettings");
        gridLayoutSpeechSettings->setContentsMargins(0, 0, 0, 0);
        label_TestText = new QLabel(groupBox_Narration);
        label_TestText->setObjectName("label_TestText");

        gridLayoutSpeechSettings->addWidget(label_TestText, 0, 0, 1, 1);

        speechTextEdit = new QPlainTextEdit(groupBox_Narration);
        speechTextEdit->setObjectName("speechTextEdit");

        gridLayoutSpeechSettings->addWidget(speechTextEdit, 0, 1, 1, 5);

        label_engine = new QLabel(groupBox_Narration);
        label_engine->setObjectName("label_engine");

        gridLayoutSpeechSettings->addWidget(label_engine, 1, 0, 1, 1);

        comboBox_Engine = new QComboBox(groupBox_Narration);
        comboBox_Engine->setObjectName("comboBox_Engine");

        gridLayoutSpeechSettings->addWidget(comboBox_Engine, 1, 1, 1, 1);

        pushButton_SpeechSay = new QPushButton(groupBox_Narration);
        pushButton_SpeechSay->setObjectName("pushButton_SpeechSay");
        QIcon icon11;
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtStart.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon11.addFile(QString::fromUtf8(":/graphicGui/uibtStart-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButton_SpeechSay->setIcon(icon11);

        gridLayoutSpeechSettings->addWidget(pushButton_SpeechSay, 1, 4, 1, 1);

        pushButton_SpeechStop = new QPushButton(groupBox_Narration);
        pushButton_SpeechStop->setObjectName("pushButton_SpeechStop");
        QIcon icon12;
        icon12.addFile(QString::fromUtf8(":/graphicGui/uibtStop.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon12.addFile(QString::fromUtf8(":/graphicGui/uibtStop-disabled.png"), QSize(), QIcon::Mode::Disabled, QIcon::State::Off);
        pushButton_SpeechStop->setIcon(icon12);

        gridLayoutSpeechSettings->addWidget(pushButton_SpeechStop, 1, 5, 1, 1);

        label_Voice = new QLabel(groupBox_Narration);
        label_Voice->setObjectName("label_Voice");

        gridLayoutSpeechSettings->addWidget(label_Voice, 2, 0, 1, 1);

        comboBox_Voice = new QComboBox(groupBox_Narration);
        comboBox_Voice->setObjectName("comboBox_Voice");
        comboBox_Voice->setMaxVisibleItems(7);

        gridLayoutSpeechSettings->addWidget(comboBox_Voice, 2, 1, 1, 3);

        label_Pitch = new QLabel(groupBox_Narration);
        label_Pitch->setObjectName("label_Pitch");

        gridLayoutSpeechSettings->addWidget(label_Pitch, 3, 0, 1, 1);

        spinBox_Pitch = new QDoubleSpinBox(groupBox_Narration);
        spinBox_Pitch->setObjectName("spinBox_Pitch");
        spinBox_Pitch->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        spinBox_Pitch->setDecimals(1);
        spinBox_Pitch->setMinimum(-1.000000000000000);
        spinBox_Pitch->setMaximum(1.000000000000000);
        spinBox_Pitch->setSingleStep(0.100000000000000);
        spinBox_Pitch->setValue(0.000000000000000);

        gridLayoutSpeechSettings->addWidget(spinBox_Pitch, 3, 1, 1, 1);

        label_Rate = new QLabel(groupBox_Narration);
        label_Rate->setObjectName("label_Rate");

        gridLayoutSpeechSettings->addWidget(label_Rate, 3, 2, 1, 1);

        spinBox_Rate = new QDoubleSpinBox(groupBox_Narration);
        spinBox_Rate->setObjectName("spinBox_Rate");
        spinBox_Rate->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        spinBox_Rate->setDecimals(1);
        spinBox_Rate->setMinimum(-1.000000000000000);
        spinBox_Rate->setMaximum(1.000000000000000);
        spinBox_Rate->setSingleStep(0.100000000000000);
        spinBox_Rate->setValue(0.000000000000000);

        gridLayoutSpeechSettings->addWidget(spinBox_Rate, 3, 3, 1, 1);

        label_Volume = new QLabel(groupBox_Narration);
        label_Volume->setObjectName("label_Volume");

        gridLayoutSpeechSettings->addWidget(label_Volume, 3, 4, 1, 1);

        spinBox_Volume = new QDoubleSpinBox(groupBox_Narration);
        spinBox_Volume->setObjectName("spinBox_Volume");
        spinBox_Volume->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        spinBox_Volume->setDecimals(1);
        spinBox_Volume->setMinimum(0.000000000000000);
        spinBox_Volume->setMaximum(1.000000000000000);
        spinBox_Volume->setSingleStep(0.100000000000000);
        spinBox_Volume->setValue(0.000000000000000);

        gridLayoutSpeechSettings->addWidget(spinBox_Volume, 3, 5, 1, 1);


        verticalLayout_Narration->addWidget(groupBox_Narration);

        configurationStackedWidget->addWidget(page_Speech);
        page_Scripts = new QWidget();
        page_Scripts->setObjectName("page_Scripts");
        horizontalLayout_7 = new QHBoxLayout(page_Scripts);
        horizontalLayout_7->setSpacing(0);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(0, 0, 0, 0);
        scriptListWidget = new QListWidget(page_Scripts);
        scriptListWidget->setObjectName("scriptListWidget");
        scriptListWidget->setFocusPolicy(Qt::NoFocus);
        scriptListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayout_7->addWidget(scriptListWidget);

        verticalLayout_8 = new QVBoxLayout();
        verticalLayout_8->setObjectName("verticalLayout_8");
        scriptInfoBrowser = new QTextBrowser(page_Scripts);
        scriptInfoBrowser->setObjectName("scriptInfoBrowser");

        verticalLayout_8->addWidget(scriptInfoBrowser);

        groupBox_8 = new QGroupBox(page_Scripts);
        groupBox_8->setObjectName("groupBox_8");
        verticalLayout_9 = new QVBoxLayout(groupBox_8);
        verticalLayout_9->setObjectName("verticalLayout_9");
        verticalLayout_9->setContentsMargins(0, 0, 0, 0);
        scriptStatusLabel = new QLabel(groupBox_8);
        scriptStatusLabel->setObjectName("scriptStatusLabel");

        verticalLayout_9->addWidget(scriptStatusLabel);

        closeWindowAtScriptRunCheckbox = new QCheckBox(groupBox_8);
        closeWindowAtScriptRunCheckbox->setObjectName("closeWindowAtScriptRunCheckbox");
        closeWindowAtScriptRunCheckbox->setChecked(true);

        verticalLayout_9->addWidget(closeWindowAtScriptRunCheckbox);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        runScriptButton = new QPushButton(groupBox_8);
        runScriptButton->setObjectName("runScriptButton");
        runScriptButton->setEnabled(true);
        runScriptButton->setIcon(icon11);

        horizontalLayout_4->addWidget(runScriptButton);

        stopScriptButton = new QPushButton(groupBox_8);
        stopScriptButton->setObjectName("stopScriptButton");
        stopScriptButton->setEnabled(true);
        stopScriptButton->setIcon(icon12);

        horizontalLayout_4->addWidget(stopScriptButton);


        verticalLayout_9->addLayout(horizontalLayout_4);


        verticalLayout_8->addWidget(groupBox_8);


        horizontalLayout_7->addLayout(verticalLayout_8);

        configurationStackedWidget->addWidget(page_Scripts);
        page_Plugins = new QWidget();
        page_Plugins->setObjectName("page_Plugins");
        horizontalLayout_6 = new QHBoxLayout(page_Plugins);
        horizontalLayout_6->setSpacing(0);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        pluginsListWidget = new QListWidget(page_Plugins);
        pluginsListWidget->setObjectName("pluginsListWidget");
        pluginsListWidget->setFocusPolicy(Qt::NoFocus);
        pluginsListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        horizontalLayout_6->addWidget(pluginsListWidget);

        pluginsVerticalLayout = new QVBoxLayout();
        pluginsVerticalLayout->setObjectName("pluginsVerticalLayout");
        pluginsInfoBrowser = new QTextBrowser(page_Plugins);
        pluginsInfoBrowser->setObjectName("pluginsInfoBrowser");
        pluginsInfoBrowser->setOpenExternalLinks(true);

        pluginsVerticalLayout->addWidget(pluginsInfoBrowser);

        pluginsGroupBox = new QGroupBox(page_Plugins);
        pluginsGroupBox->setObjectName("pluginsGroupBox");
        horizontalLayout_8 = new QHBoxLayout(pluginsGroupBox);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(0, 0, 0, 0);
        pluginLoadAtStartupCheckBox = new QCheckBox(pluginsGroupBox);
        pluginLoadAtStartupCheckBox->setObjectName("pluginLoadAtStartupCheckBox");

        horizontalLayout_8->addWidget(pluginLoadAtStartupCheckBox);

        pluginConfigureButton = new QPushButton(pluginsGroupBox);
        pluginConfigureButton->setObjectName("pluginConfigureButton");
        pluginConfigureButton->setEnabled(false);

        horizontalLayout_8->addWidget(pluginConfigureButton);


        pluginsVerticalLayout->addWidget(pluginsGroupBox);


        horizontalLayout_6->addLayout(pluginsVerticalLayout);

        configurationStackedWidget->addWidget(page_Plugins);

        gridLayout->addWidget(configurationStackedWidget, 1, 0, 1, 1);


        vboxLayout->addWidget(viewContent);

        QWidget::setTabOrder(programLanguageComboBox, languageSaveToolButton);
        QWidget::setTabOrder(languageSaveToolButton, de440checkBox);
        QWidget::setTabOrder(de440checkBox, de441checkBox);
        QWidget::setTabOrder(de441checkBox, de430checkBox);
        QWidget::setTabOrder(de430checkBox, de431checkBox);
        QWidget::setTabOrder(de431checkBox, saveViewDirAsDefaultPushButton);
        QWidget::setTabOrder(saveViewDirAsDefaultPushButton, saveSettingsAsDefaultPushButton);
        QWidget::setTabOrder(saveSettingsAsDefaultPushButton, immediateSaveCheckBox);
        QWidget::setTabOrder(immediateSaveCheckBox, restoreDefaultsButton);
        QWidget::setTabOrder(restoreDefaultsButton, allSelectedInfoRadio);
        QWidget::setTabOrder(allSelectedInfoRadio, defaultSelectedInfoRadio);
        QWidget::setTabOrder(defaultSelectedInfoRadio, briefSelectedInfoRadio);
        QWidget::setTabOrder(briefSelectedInfoRadio, noSelectedInfoRadio);
        QWidget::setTabOrder(noSelectedInfoRadio, customSelectedInfoRadio);
        QWidget::setTabOrder(customSelectedInfoRadio, checkBoxName);
        QWidget::setTabOrder(checkBoxName, checkBoxCatalogNumbers);
        QWidget::setTabOrder(checkBoxCatalogNumbers, checkBoxRaDecJ2000);
        QWidget::setTabOrder(checkBoxRaDecJ2000, checkBoxRaDecOfDate);
        QWidget::setTabOrder(checkBoxRaDecOfDate, checkBoxHourAngle);
        QWidget::setTabOrder(checkBoxHourAngle, checkBoxAltAz);
        QWidget::setTabOrder(checkBoxAltAz, checkBoxEclipticCoordsJ2000);
        QWidget::setTabOrder(checkBoxEclipticCoordsJ2000, checkBoxEclipticCoordsOfDate);
        QWidget::setTabOrder(checkBoxEclipticCoordsOfDate, checkBoxGalacticCoordinates);
        QWidget::setTabOrder(checkBoxGalacticCoordinates, checkBoxSupergalacticCoordinates);
        QWidget::setTabOrder(checkBoxSupergalacticCoordinates, checkBoxOtherCoords);
        QWidget::setTabOrder(checkBoxOtherCoords, checkBoxElongation);
        QWidget::setTabOrder(checkBoxElongation, checkBoxVisualMag);
        QWidget::setTabOrder(checkBoxVisualMag, checkBoxAbsoluteMag);
        QWidget::setTabOrder(checkBoxAbsoluteMag, checkBoxType);
        QWidget::setTabOrder(checkBoxType, checkBoxSize);
        QWidget::setTabOrder(checkBoxSize, checkBoxVelocity);
        QWidget::setTabOrder(checkBoxVelocity, checkBoxProperMotion);
        QWidget::setTabOrder(checkBoxProperMotion, checkBoxDistance);
        QWidget::setTabOrder(checkBoxDistance, checkBoxSiderealTime);
        QWidget::setTabOrder(checkBoxSiderealTime, checkBoxConstellation);
        QWidget::setTabOrder(checkBoxConstellation, checkBoxRTSTime);
        QWidget::setTabOrder(checkBoxRTSTime, checkBoxSolarLunarPosition);
        QWidget::setTabOrder(checkBoxSolarLunarPosition, checkBoxExtra);
        QWidget::setTabOrder(checkBoxExtra, checkBoxUMSurfaceBrightness);
        QWidget::setTabOrder(checkBoxUMSurfaceBrightness, checkBoxUMShortNotationSurfaceBrightness);
        QWidget::setTabOrder(checkBoxUMShortNotationSurfaceBrightness, checkBoxUseCCSDesignations);
        QWidget::setTabOrder(checkBoxUseCCSDesignations, checkBoxUseFormattingOutput);
        QWidget::setTabOrder(checkBoxUseFormattingOutput, checkBoxDecimalDegrees);
        QWidget::setTabOrder(checkBoxDecimalDegrees, checkBoxAzimuthFromSouth);
        QWidget::setTabOrder(checkBoxAzimuthFromSouth, checkBoxNegativeHourAngles);
        QWidget::setTabOrder(checkBoxNegativeHourAngles, checkBoxPolarDistance);
        QWidget::setTabOrder(checkBoxPolarDistance, showConstellationBoundariesButtonCheckBox);
        QWidget::setTabOrder(showConstellationBoundariesButtonCheckBox, showConstellationArtsButtonCheckBox);
        QWidget::setTabOrder(showConstellationArtsButtonCheckBox, showAsterismLinesButtonCheckBox);
        QWidget::setTabOrder(showAsterismLinesButtonCheckBox, showAsterismLabelsButtonCheckBox);
        QWidget::setTabOrder(showAsterismLabelsButtonCheckBox, showEclipticGridButtonCheckBox);
        QWidget::setTabOrder(showEclipticGridButtonCheckBox, showICRSGridButtonCheckBox);
        QWidget::setTabOrder(showICRSGridButtonCheckBox, showGalacticGridButtonCheckBox);
        QWidget::setTabOrder(showGalacticGridButtonCheckBox, showCardinalButtonCheckBox);
        QWidget::setTabOrder(showCardinalButtonCheckBox, showCompassButtonCheckBox);
        QWidget::setTabOrder(showCompassButtonCheckBox, showNightmodeButtonCheckBox);
        QWidget::setTabOrder(showNightmodeButtonCheckBox, showGotoSelectedButtonCheckBox);
        QWidget::setTabOrder(showGotoSelectedButtonCheckBox, showFullscreenButtonCheckBox);
        QWidget::setTabOrder(showFullscreenButtonCheckBox, showQuitButtonCheckBox);
        QWidget::setTabOrder(showQuitButtonCheckBox, showNebulaBgButtonCheckbox);
        QWidget::setTabOrder(showNebulaBgButtonCheckbox, showFlipButtonsCheckbox);
        QWidget::setTabOrder(showFlipButtonsCheckbox, showDSSButtonCheckbox);
        QWidget::setTabOrder(showDSSButtonCheckbox, showHipsButtonCheckBox);
        QWidget::setTabOrder(showHipsButtonCheckBox, useButtonsBackgroundCheckBox);
        QWidget::setTabOrder(useButtonsBackgroundCheckBox, showObsListButtonCheckBox);
        QWidget::setTabOrder(showObsListButtonCheckBox, getStarsButton);
        QWidget::setTabOrder(getStarsButton, downloadRetryButton);
        QWidget::setTabOrder(downloadRetryButton, downloadCancelButton);
        QWidget::setTabOrder(downloadCancelButton, systemTimeRadio);
        QWidget::setTabOrder(systemTimeRadio, todayRadio);
        QWidget::setTabOrder(todayRadio, todayTimeSpinBox);
        QWidget::setTabOrder(todayTimeSpinBox, fixedTimeRadio);
        QWidget::setTabOrder(fixedTimeRadio, fixedDateTimeEdit);
        QWidget::setTabOrder(fixedDateTimeEdit, fixedDateTimeCurrentButton);
        QWidget::setTabOrder(fixedDateTimeCurrentButton, startupTimeStopCheckBox);
        QWidget::setTabOrder(startupTimeStopCheckBox, jdRadioButton);
        QWidget::setTabOrder(jdRadioButton, dtRadioButton);
        QWidget::setTabOrder(dtRadioButton, dateFormatsComboBox);
        QWidget::setTabOrder(dateFormatsComboBox, timeFormatsComboBox);
        QWidget::setTabOrder(timeFormatsComboBox, deltaTAlgorithmComboBox);
        QWidget::setTabOrder(deltaTAlgorithmComboBox, pushButtonCustomDeltaTEquationDialog);
        QWidget::setTabOrder(pushButtonCustomDeltaTEquationDialog, deltaTAlgorithmDescription);
        QWidget::setTabOrder(deltaTAlgorithmDescription, sphericMirrorCheckbox);
        QWidget::setTabOrder(sphericMirrorCheckbox, diskViewportCheckbox);
        QWidget::setTabOrder(diskViewportCheckbox, gravityLabelCheckbox);
        QWidget::setTabOrder(gravityLabelCheckbox, autoZoomResetsDirectionCheckbox);
        QWidget::setTabOrder(autoZoomResetsDirectionCheckbox, enableKeysNavigationCheckBox);
        QWidget::setTabOrder(enableKeysNavigationCheckBox, editShortcutsPushButton);
        QWidget::setTabOrder(editShortcutsPushButton, enableMouseNavigationCheckBox);
        QWidget::setTabOrder(enableMouseNavigationCheckBox, enableMouseZoomingCheckBox);
        QWidget::setTabOrder(enableMouseZoomingCheckBox, mouseTimeoutCheckbox);
        QWidget::setTabOrder(mouseTimeoutCheckbox, mouseTimeoutSpinBox);
        QWidget::setTabOrder(mouseTimeoutSpinBox, overwriteTextColorButton);
        QWidget::setTabOrder(overwriteTextColorButton, overwriteTextColorCheckBox);
        QWidget::setTabOrder(overwriteTextColorCheckBox, screenFontSizeSpinBox);
        QWidget::setTabOrder(screenFontSizeSpinBox, guiFontSizeSpinBox);
        QWidget::setTabOrder(guiFontSizeSpinBox, topocentricCheckBox);
        QWidget::setTabOrder(topocentricCheckBox, nutationCheckBox);
        QWidget::setTabOrder(nutationCheckBox, aberrationCheckBox);
        QWidget::setTabOrder(aberrationCheckBox, aberrationSpinBox);
        QWidget::setTabOrder(aberrationSpinBox, minFpsSpinBox);
        QWidget::setTabOrder(minFpsSpinBox, maxFpsSpinBox);
        QWidget::setTabOrder(maxFpsSpinBox, solarSystemThreadNumberSpinBox);
        QWidget::setTabOrder(solarSystemThreadNumberSpinBox, focusOnDaySpinnerCheckBox);
        QWidget::setTabOrder(focusOnDaySpinnerCheckBox, kineticScrollingCheckBox);
        QWidget::setTabOrder(kineticScrollingCheckBox, ditheringComboBox);
        QWidget::setTabOrder(ditheringComboBox, indicationMountModeCheckBox);
        QWidget::setTabOrder(indicationMountModeCheckBox, daylightTextColorButton);
        QWidget::setTabOrder(daylightTextColorButton, fontWritingSystemComboBox);
        QWidget::setTabOrder(fontWritingSystemComboBox, fontComboBox);
        QWidget::setTabOrder(fontComboBox, fontSaveToolButton);
        QWidget::setTabOrder(fontSaveToolButton, screenshotDirEdit);
        QWidget::setTabOrder(screenshotDirEdit, screenshotBrowseButton);
        QWidget::setTabOrder(screenshotBrowseButton, pushButtonConfigureScreenshotsDialog);
        QWidget::setTabOrder(pushButtonConfigureScreenshotsDialog, screenshotFileFormatComboBox);
        QWidget::setTabOrder(screenshotFileFormatComboBox, invertScreenShotColorsCheckBox);
        QWidget::setTabOrder(invertScreenShotColorsCheckBox, useCustomScreenshotSizeCheckBox);
        QWidget::setTabOrder(useCustomScreenshotSizeCheckBox, customScreenshotWidthLineEdit);
        QWidget::setTabOrder(customScreenshotWidthLineEdit, customScreenshotHeightLineEdit);
        QWidget::setTabOrder(customScreenshotHeightLineEdit, dpiSpinBox);
        QWidget::setTabOrder(dpiSpinBox, scriptInfoBrowser);
        QWidget::setTabOrder(scriptInfoBrowser, closeWindowAtScriptRunCheckbox);
        QWidget::setTabOrder(closeWindowAtScriptRunCheckbox, runScriptButton);
        QWidget::setTabOrder(runScriptButton, stopScriptButton);
        QWidget::setTabOrder(stopScriptButton, pluginsInfoBrowser);
        QWidget::setTabOrder(pluginsInfoBrowser, pluginLoadAtStartupCheckBox);
        QWidget::setTabOrder(pluginLoadAtStartupCheckBox, pluginConfigureButton);

        retranslateUi(configurationDialogForm);
        QObject::connect(stackListWidget, &QListWidget::currentRowChanged, configurationStackedWidget, &QStackedWidget::setCurrentIndex);

        configurationStackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(configurationDialogForm);
    } // setupUi

    void retranslateUi(QWidget *configurationDialogForm)
    {
        titleBar->setProperty("title", QVariant(QCoreApplication::translate("configurationDialogForm", "Configuration", nullptr)));

        const bool __sortingEnabled = stackListWidget->isSortingEnabled();
        stackListWidget->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = stackListWidget->item(0);
        ___qlistwidgetitem->setText(QCoreApplication::translate("configurationDialogForm", "Main", nullptr));
        QListWidgetItem *___qlistwidgetitem1 = stackListWidget->item(1);
        ___qlistwidgetitem1->setText(QCoreApplication::translate("configurationDialogForm", "Information", nullptr));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem1->setToolTip(QCoreApplication::translate("configurationDialogForm", "Selected object information", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem2 = stackListWidget->item(2);
        ___qlistwidgetitem2->setText(QCoreApplication::translate("configurationDialogForm", "Extras", "Additional settings for Graphical User Interface"));
#if QT_CONFIG(tooltip)
        ___qlistwidgetitem2->setToolTip(QCoreApplication::translate("configurationDialogForm", "Additional settings for Graphical User Interface", nullptr));
#endif // QT_CONFIG(tooltip)
        QListWidgetItem *___qlistwidgetitem3 = stackListWidget->item(3);
        ___qlistwidgetitem3->setText(QCoreApplication::translate("configurationDialogForm", "Time", nullptr));
        QListWidgetItem *___qlistwidgetitem4 = stackListWidget->item(4);
        ___qlistwidgetitem4->setText(QCoreApplication::translate("configurationDialogForm", "Tools", nullptr));
        QListWidgetItem *___qlistwidgetitem5 = stackListWidget->item(5);
        ___qlistwidgetitem5->setText(QCoreApplication::translate("configurationDialogForm", "Speech", nullptr));
        QListWidgetItem *___qlistwidgetitem6 = stackListWidget->item(6);
        ___qlistwidgetitem6->setText(QCoreApplication::translate("configurationDialogForm", "Scripts", nullptr));
        QListWidgetItem *___qlistwidgetitem7 = stackListWidget->item(7);
        ___qlistwidgetitem7->setText(QCoreApplication::translate("configurationDialogForm", "Plugins", nullptr));
        stackListWidget->setSortingEnabled(__sortingEnabled);

        groupBox_LanguageSettings->setTitle(QCoreApplication::translate("configurationDialogForm", "Language settings", nullptr));
        programLanguageLabel->setText(QCoreApplication::translate("configurationDialogForm", "Program Language", nullptr));
#if QT_CONFIG(tooltip)
        languageSaveToolButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Store language settings", nullptr));
#endif // QT_CONFIG(tooltip)
        languageSaveToolButton->setText(QCoreApplication::translate("configurationDialogForm", "Save", nullptr));
#if QT_CONFIG(tooltip)
        groupBox_EphemerisSettings->setToolTip(QCoreApplication::translate("configurationDialogForm", "See User Guide for adding ephemeris data.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_EphemerisSettings->setTitle(QCoreApplication::translate("configurationDialogForm", "Ephemeris settings", nullptr));
        de431label->setText(QCoreApplication::translate("configurationDialogForm", "Not installed", nullptr));
        de430checkBox->setText(QCoreApplication::translate("configurationDialogForm", "Use DE430 (high accuracy)", nullptr));
#if QT_CONFIG(tooltip)
        de440checkBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "DE440 provides highest accuracy, only for years 1550...2650.", nullptr));
#endif // QT_CONFIG(tooltip)
        de440checkBox->setText(QCoreApplication::translate("configurationDialogForm", "Use DE440 (high accuracy)", nullptr));
#if QT_CONFIG(tooltip)
        de431checkBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "DE431 provides position data for years -13000...+17000. For special applications only.", nullptr));
#endif // QT_CONFIG(tooltip)
        de431checkBox->setText(QCoreApplication::translate("configurationDialogForm", "Use DE431 (long-time data)", nullptr));
        de440label->setText(QCoreApplication::translate("configurationDialogForm", "Not installed", nullptr));
#if QT_CONFIG(tooltip)
        de441checkBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "DE441 provides position data for years -13000...+17000. For special applications only.", nullptr));
#endif // QT_CONFIG(tooltip)
        de441checkBox->setText(QCoreApplication::translate("configurationDialogForm", "Use DE441 (long-time data)", nullptr));
        de441label->setText(QCoreApplication::translate("configurationDialogForm", "Not installed", nullptr));
        de430label->setText(QCoreApplication::translate("configurationDialogForm", "Not installed", nullptr));
#if QT_CONFIG(tooltip)
        label_VSOP87used->setToolTip(QCoreApplication::translate("configurationDialogForm", "Using VSOP87 is recommended for years -4000...+8000 only, but delivers useful positions outside this range.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_VSOP87used->setText(QCoreApplication::translate("configurationDialogForm", "VSOP87/ELP2000-82B is used when these are not installed or not activated.", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("configurationDialogForm", "Default options", nullptr));
        saveViewDirAsDefaultPushButton->setText(QCoreApplication::translate("configurationDialogForm", "Save view", nullptr));
#if QT_CONFIG(whatsthis)
        saveSettingsAsDefaultPushButton->setWhatsThis(QCoreApplication::translate("configurationDialogForm", "Save the settings you've changed this session to be the same the next time you start Stellarium", nullptr));
#endif // QT_CONFIG(whatsthis)
        saveSettingsAsDefaultPushButton->setText(QCoreApplication::translate("configurationDialogForm", "Save settings", nullptr));
#if QT_CONFIG(tooltip)
        immediateSaveCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Store changes immediately. This makes pressing \"Save settings\" no longer necessary, the button is then disabled.", nullptr));
#endif // QT_CONFIG(tooltip)
        immediateSaveCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Immediate Save", nullptr));
#if QT_CONFIG(whatsthis)
        restoreDefaultsButton->setWhatsThis(QCoreApplication::translate("configurationDialogForm", "Restore the default settings that came with Stellarium", nullptr));
#endif // QT_CONFIG(whatsthis)
        restoreDefaultsButton->setText(QCoreApplication::translate("configurationDialogForm", "Restore defaults", nullptr));
        saveDefaultOptionsLabel->setText(QCoreApplication::translate("configurationDialogForm", "Save either the current FOV and direction of view or all the current options for use at next startup. Restoring default settings requires a restart of Stellarium. ", nullptr));
#if QT_CONFIG(statustip)
        startupFOVLabel->setStatusTip(QCoreApplication::translate("configurationDialogForm", "The vertical field (height) of your view when Stellarium starts", nullptr));
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(statustip)
        startupDirectionOfViewlabel->setStatusTip(QCoreApplication::translate("configurationDialogForm", "The direction you're looking when Stellarium starts", nullptr));
#endif // QT_CONFIG(statustip)
        selectedInfoGroupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Selected object information for display", nullptr));
#if QT_CONFIG(tooltip)
        allSelectedInfoRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Display all information available", nullptr));
#endif // QT_CONFIG(tooltip)
        allSelectedInfoRadio->setText(QCoreApplication::translate("configurationDialogForm", "All available", "info group name"));
#if QT_CONFIG(tooltip)
        defaultSelectedInfoRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Display a preconfigured set of information", nullptr));
#endif // QT_CONFIG(tooltip)
        defaultSelectedInfoRadio->setText(QCoreApplication::translate("configurationDialogForm", "Default", "info group name"));
#if QT_CONFIG(tooltip)
        briefSelectedInfoRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Display less information", nullptr));
#endif // QT_CONFIG(tooltip)
        briefSelectedInfoRadio->setText(QCoreApplication::translate("configurationDialogForm", "Short", "info group name"));
#if QT_CONFIG(tooltip)
        noSelectedInfoRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Display no information", nullptr));
#endif // QT_CONFIG(tooltip)
        noSelectedInfoRadio->setText(QCoreApplication::translate("configurationDialogForm", "None", "info group name"));
#if QT_CONFIG(tooltip)
        customSelectedInfoRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Display user customized information", nullptr));
#endif // QT_CONFIG(tooltip)
        customSelectedInfoRadio->setText(QCoreApplication::translate("configurationDialogForm", "Customized", "info group name"));
        groupBoxDisplayedFields->setTitle(QCoreApplication::translate("configurationDialogForm", "Displayed fields/narrated items", nullptr));
        checkBoxName->setText(QString());
        label_infoName->setText(QCoreApplication::translate("configurationDialogForm", "Name", nullptr));
        checkBoxCatalogNumbers->setText(QString());
        label_infoCat->setText(QCoreApplication::translate("configurationDialogForm", "Catalog number(s)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRaDecJ2000->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of J2000.0", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxRaDecJ2000->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxRaDecJ2000_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of J2000.0", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoRaDec2000->setText(QCoreApplication::translate("configurationDialogForm", "Right ascension/Declination (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRaDecOfDate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of date", "right ascension"));
#endif // QT_CONFIG(tooltip)
        checkBoxRaDecOfDate->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxRaDecOfDate_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of date", "right ascension"));
#endif // QT_CONFIG(tooltip)
        label_infoRaDec->setText(QCoreApplication::translate("configurationDialogForm", "Right ascension/Declination (of date)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHourAngle->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of date", "hour angle"));
#endif // QT_CONFIG(tooltip)
        checkBoxHourAngle->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxHourAngle_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Equatorial coordinates, equinox of date", "hour angle"));
#endif // QT_CONFIG(tooltip)
        label_infoHADec->setText(QCoreApplication::translate("configurationDialogForm", "Hour angle/Declination", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAltAz->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        checkBoxAltAz->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxAltAz_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Horizontal coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoAltAz->setText(QCoreApplication::translate("configurationDialogForm", "Azimuth/Altitude", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxEclipticCoordsJ2000->setToolTip(QCoreApplication::translate("configurationDialogForm", "Ecliptic coordinates, equinox J2000.0", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxEclipticCoordsJ2000->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxEclipticCoordsJ2000_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Ecliptic coordinates, equinox J2000.0", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoEcl2000->setText(QCoreApplication::translate("configurationDialogForm", "Ecliptic coordinates (J2000)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxEclipticCoordsOfDate->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        checkBoxEclipticCoordsOfDate->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxEclipticCoordsOfDate_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Ecliptic coordinates, equinox of date (only for Earth)", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoEcl->setText(QCoreApplication::translate("configurationDialogForm", "Ecliptic coordinates (of date)", nullptr));
        checkBoxGalacticCoordinates->setText(QString());
        label_infoGalCoords->setText(QCoreApplication::translate("configurationDialogForm", "Galactic coordinates", nullptr));
        checkBoxSupergalacticCoordinates->setText(QString());
        label_infoSGalCoords->setText(QCoreApplication::translate("configurationDialogForm", "Supergalactic coordinates", nullptr));
        checkBoxOtherCoords->setText(QString());
        label_infoOtherCoords->setText(QCoreApplication::translate("configurationDialogForm", "Additional coordinates (from plugins)", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxElongation->setToolTip(QCoreApplication::translate("configurationDialogForm", "Elongation and phase angle", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxElongation->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxElongation_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Elongation and phase angle", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoElongation->setText(QCoreApplication::translate("configurationDialogForm", "Elongation", nullptr));
        checkBoxVisualMag->setText(QString());
        label_infoVisualMag->setText(QCoreApplication::translate("configurationDialogForm", "Visual magnitude", nullptr));
        checkBoxAbsoluteMag->setText(QString());
        label_infoAbsoluteMag->setText(QCoreApplication::translate("configurationDialogForm", "Absolute magnitude", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxType->setToolTip(QCoreApplication::translate("configurationDialogForm", "The type of the object (star, planet, etc.)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxType->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxType_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "The type of the object (star, planet, etc.)", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoType->setText(QCoreApplication::translate("configurationDialogForm", "Type", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSize->setToolTip(QCoreApplication::translate("configurationDialogForm", "Angular or physical size", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSize->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxSize_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Angular or physical size", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoSize->setText(QCoreApplication::translate("configurationDialogForm", "Size", nullptr));
        checkBoxVelocity->setText(QString());
        label_infoVelocity->setText(QCoreApplication::translate("configurationDialogForm", "Velocity", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxProperMotion->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        checkBoxProperMotion->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxProperMotion_Narrate->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label_infoProperMotion->setText(QCoreApplication::translate("configurationDialogForm", "Proper Motion", nullptr));
        checkBoxDistance->setText(QString());
        label_infoDistance->setText(QCoreApplication::translate("configurationDialogForm", "Distance", nullptr));
        checkBoxSiderealTime->setText(QString());
        label_infoSiderealTime->setText(QCoreApplication::translate("configurationDialogForm", "Sidereal time", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxConstellation->setToolTip(QCoreApplication::translate("configurationDialogForm", "3-letter IAU constellation abbreviation", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxConstellation->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxConstellation_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Voice output of constellation", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoConstellation->setText(QCoreApplication::translate("configurationDialogForm", "Constellation", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxRTSTime->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        checkBoxRTSTime->setText(QString());
        label_infoRTS->setText(QCoreApplication::translate("configurationDialogForm", "Risings, Transits, and Settings", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSolarLunarPosition->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show Solar and Lunar positions if observed from Earth", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSolarLunarPosition->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxSolarLunarPosition_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Voice output of Solar and Lunar positions if observed from Earth", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoSolarLunarPosition->setText(QCoreApplication::translate("configurationDialogForm", "Solar and Lunar position", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxExtra->setToolTip(QCoreApplication::translate("configurationDialogForm", "Spectral class, nebula type, etc.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxExtra->setText(QString());
#if QT_CONFIG(tooltip)
        checkBoxExtra_Narrate->setToolTip(QCoreApplication::translate("configurationDialogForm", "Spectral class, nebula type, etc.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_infoExtra->setText(QCoreApplication::translate("configurationDialogForm", "Additional information", nullptr));
        contentBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Star catalog updates", nullptr));
#if QT_CONFIG(tooltip)
        getStarsButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Click here to start downloading", nullptr));
#endif // QT_CONFIG(tooltip)
        getStarsButton->setDescription(QCoreApplication::translate("configurationDialogForm", "Download this file to view even more stars", nullptr));
#if QT_CONFIG(tooltip)
        downloadRetryButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Restart the download", nullptr));
#endif // QT_CONFIG(tooltip)
        downloadRetryButton->setText(QCoreApplication::translate("configurationDialogForm", "Retry", nullptr));
#if QT_CONFIG(tooltip)
        downloadCancelButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Stop the download. You can always restart it later", nullptr));
#endif // QT_CONFIG(tooltip)
        downloadCancelButton->setText(QCoreApplication::translate("configurationDialogForm", "Cancel", nullptr));
        groupBoxAdditionalSettings->setTitle(QCoreApplication::translate("configurationDialogForm", "Additional information settings", nullptr));
        checkBoxUMShortNotationSurfaceBrightness->setText(QCoreApplication::translate("configurationDialogForm", "Short notation for units of surface brightness", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxDecimalDegrees->setToolTip(QCoreApplication::translate("configurationDialogForm", "Use decimal degrees for coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDecimalDegrees->setText(QCoreApplication::translate("configurationDialogForm", "Use decimal degrees", nullptr));
        checkBoxUMSurfaceBrightness->setText(QCoreApplication::translate("configurationDialogForm", "Use mag/arcsec^2 for surface brightness", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAzimuthFromSouth->setToolTip(QCoreApplication::translate("configurationDialogForm", "Activate this option to calculate azimuth from south towards west.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAzimuthFromSouth->setText(QCoreApplication::translate("configurationDialogForm", "Azimuth from South", nullptr));
        checkBoxUseFormattingOutput->setText(QCoreApplication::translate("configurationDialogForm", "Tabular output for coordinates and time", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxUseCCSDesignations->setToolTip(QCoreApplication::translate("configurationDialogForm", "Use common symbols for coordinate systems", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxUseCCSDesignations->setText(QCoreApplication::translate("configurationDialogForm", "Designations for celestial coordinate systems", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPolarDistance->setToolTip(QCoreApplication::translate("configurationDialogForm", "Use distance from North Celestial Pole, not declination from equator in equatorial coordinates", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPolarDistance->setText(QCoreApplication::translate("configurationDialogForm", "Polar distance, not declination", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNegativeHourAngles->setToolTip(QCoreApplication::translate("configurationDialogForm", "Hour angles usually run 0...24h. This counts -12h...12h.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNegativeHourAngles->setText(QCoreApplication::translate("configurationDialogForm", "Allow negative hour angles ", nullptr));
        groupBoxAdditionalButtons->setTitle(QCoreApplication::translate("configurationDialogForm", "Show additional buttons", nullptr));
#if QT_CONFIG(tooltip)
        showObsListButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Enable a feature to store favorite views.", nullptr));
#endif // QT_CONFIG(tooltip)
        showObsListButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Observing lists", nullptr));
#if QT_CONFIG(tooltip)
        showGalacticGridButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "A button to toggle galactic grid", nullptr));
#endif // QT_CONFIG(tooltip)
        showGalacticGridButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Galactic grid", nullptr));
        showConstellationBoundariesButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Constellation boundaries", nullptr));
        showConstellationArtsButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Constellation art", nullptr));
#if QT_CONFIG(tooltip)
        showICRSGridButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "A button to toggle equatorial J2000 grid", nullptr));
#endif // QT_CONFIG(tooltip)
        showICRSGridButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "ICRS grid", nullptr));
#if QT_CONFIG(tooltip)
        showEclipticGridButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "A button to toggle ecliptic grid of date", nullptr));
#endif // QT_CONFIG(tooltip)
        showEclipticGridButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Ecliptic grid", nullptr));
        showAsterismLinesButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Asterism lines", nullptr));
        showAsterismLabelsButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Asterism labels", nullptr));
#if QT_CONFIG(tooltip)
        showCardinalButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showCardinalButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Cardinal points", nullptr));
#if QT_CONFIG(tooltip)
        showCompassButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showCompassButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Compass marks", nullptr));
#if QT_CONFIG(tooltip)
        showNebulaBgButtonCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Toggle display of nebula images.", nullptr));
#endif // QT_CONFIG(tooltip)
        showNebulaBgButtonCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Nebula background", nullptr));
#if QT_CONFIG(tooltip)
        showFlipButtonsCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Toggle vertical and horizontal image flip buttons.", nullptr));
#endif // QT_CONFIG(tooltip)
        showFlipButtonsCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Flip buttons", nullptr));
#if QT_CONFIG(tooltip)
        showDSSButtonCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Toggle display of the button for the Digitized Sky Survey.", nullptr));
#endif // QT_CONFIG(tooltip)
        showDSSButtonCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "DSS survey", nullptr));
#if QT_CONFIG(tooltip)
        showHipsButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Toggle display of the button for the HiPS Surveys. Select a survey in the View settings.", nullptr));
#endif // QT_CONFIG(tooltip)
        showHipsButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "HiPS Surveys", nullptr));
#if QT_CONFIG(tooltip)
        useButtonsBackgroundCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Toggle the usage of background under GUI buttons", nullptr));
#endif // QT_CONFIG(tooltip)
        useButtonsBackgroundCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Use buttons background", nullptr));
#if QT_CONFIG(tooltip)
        showNightmodeButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showNightmodeButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Night mode", nullptr));
#if QT_CONFIG(tooltip)
        showGotoSelectedButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showGotoSelectedButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Centering button", nullptr));
#if QT_CONFIG(tooltip)
        showFullscreenButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showFullscreenButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Fullscreen button", nullptr));
#if QT_CONFIG(tooltip)
        showQuitButtonCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Show button in addition to keyboard shortcut?", nullptr));
#endif // QT_CONFIG(tooltip)
        showQuitButtonCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Quit button", nullptr));
        timeGroupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Startup date and time", nullptr));
        startupTimeStopCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Stop clock when starting", nullptr));
#if QT_CONFIG(tooltip)
        fixedTimeRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Use a specific date and time when Stellarium starts up", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedTimeRadio->setText(QCoreApplication::translate("configurationDialogForm", "Other:", nullptr));
#if QT_CONFIG(tooltip)
        todayRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Sets the simulation time to the next instance of this time of day when Stellarium starts", nullptr));
#endif // QT_CONFIG(tooltip)
        todayRadio->setText(QCoreApplication::translate("configurationDialogForm", "System date at:", nullptr));
#if QT_CONFIG(tooltip)
        fixedDateTimeCurrentButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Use current local date and time", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedDateTimeCurrentButton->setText(QCoreApplication::translate("configurationDialogForm", "use current", nullptr));
#if QT_CONFIG(tooltip)
        systemTimeRadio->setToolTip(QCoreApplication::translate("configurationDialogForm", "Starts Stellarium at system clock date and time", nullptr));
#endif // QT_CONFIG(tooltip)
        systemTimeRadio->setText(QCoreApplication::translate("configurationDialogForm", "System date and time", nullptr));
#if QT_CONFIG(tooltip)
        timeDisplayFormatsGroupBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "These settings control the way time and date are displayed in the bottom bar.", nullptr));
#endif // QT_CONFIG(tooltip)
        timeDisplayFormatsGroupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Display formats of date and time", nullptr));
        timeFormatsLabel->setText(QCoreApplication::translate("configurationDialogForm", "and time:", nullptr));
        dtRadioButton->setText(QCoreApplication::translate("configurationDialogForm", "Date:", nullptr));
        deltaTGroupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Time correction", nullptr));
        deltaTLabel->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonCustomDeltaTEquationDialog->setToolTip(QCoreApplication::translate("configurationDialogForm", "Edit equation", nullptr));
#endif // QT_CONFIG(tooltip)
        planetarium_groupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Planetarium options", nullptr));
#if QT_CONFIG(tooltip)
        mouseTimeoutCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Hides the mouse cursor when inactive", nullptr));
#endif // QT_CONFIG(tooltip)
        mouseTimeoutCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Mouse cursor timeout:", nullptr));
#if QT_CONFIG(tooltip)
        mouseTimeoutSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "seconds", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        diskViewportCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Mask out everything outside a central circle in the main view", nullptr));
#endif // QT_CONFIG(tooltip)
        diskViewportCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Disc viewport", nullptr));
#if QT_CONFIG(tooltip)
        kineticScrollingCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Kinetic scrolling means dragging text panels directly instead of dragging window handles.", nullptr));
#endif // QT_CONFIG(tooltip)
        kineticScrollingCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Use kinetic scrolling", nullptr));
#if QT_CONFIG(tooltip)
        daylightTextColorButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Info text color at daylight", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("configurationDialogForm", "Info text color at daylight", nullptr));
#if QT_CONFIG(tooltip)
        enableMouseNavigationCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Allow mouse to pan (drag)", nullptr));
#endif // QT_CONFIG(tooltip)
        enableMouseNavigationCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Enable mouse navigation", nullptr));
#if QT_CONFIG(tooltip)
        parallaxCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Parallax is the apparent shift in the position of an object when viewed from two different points.", nullptr));
#endif // QT_CONFIG(tooltip)
        parallaxCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Parallax", nullptr));
#if QT_CONFIG(tooltip)
        parallaxSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Exaggerate parallax (for didactic explanations)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        aberrationCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Annual aberration is an annual wobble in positions, amounting to max. about 20 arcseconds for observers on Earth.", nullptr));
#endif // QT_CONFIG(tooltip)
        aberrationCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Aberration", nullptr));
#if QT_CONFIG(tooltip)
        aberrationSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Exaggerate aberration (for didactic explanations)", nullptr));
#endif // QT_CONFIG(tooltip)
        label_Include->setText(QCoreApplication::translate("configurationDialogForm", "Include ", nullptr));
#if QT_CONFIG(tooltip)
        nutationCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Nutation is a small wobble of Earth's axis, amounting to a few arcseconds.", nullptr));
#endif // QT_CONFIG(tooltip)
        nutationCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Nutation", nullptr));
#if QT_CONFIG(tooltip)
        topocentricCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Activate to view as seen from surface of the planet (recommended). If switched off, display planetocentric view.", nullptr));
#endif // QT_CONFIG(tooltip)
        topocentricCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Topocentric coordinates", nullptr));
        label_fpsIntent->setText(QCoreApplication::translate("configurationDialogForm", "Framerate intent:", nullptr));
        label_min->setText(QCoreApplication::translate("configurationDialogForm", "min:", nullptr));
#if QT_CONFIG(tooltip)
        minFpsSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Minimum intended FPS between user interaction. Set very low to conserve energy or save CPU use.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_max->setText(QCoreApplication::translate("configurationDialogForm", "max:", nullptr));
#if QT_CONFIG(tooltip)
        maxFpsSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Maximum allowed FPS. 1000 just means \"as fast as possible\". ", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        enableKeysNavigationCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Allow keyboard to pan and zoom", nullptr));
#endif // QT_CONFIG(tooltip)
        enableKeysNavigationCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Enable keyboard navigation", nullptr));
#if QT_CONFIG(tooltip)
        editShortcutsPushButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Edit keyboard shortcuts...", nullptr));
#endif // QT_CONFIG(tooltip)
        dithering_label->setText(QCoreApplication::translate("configurationDialogForm", "Dithering", nullptr));
#if QT_CONFIG(tooltip)
        gravityLabelCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Align labels with the screen center", nullptr));
#endif // QT_CONFIG(tooltip)
        gravityLabelCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Gravity labels", nullptr));
#if QT_CONFIG(tooltip)
        sphericMirrorCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Spheric mirror distortion is used when projecting Stellarium onto a spheric mirror for low-cost planetarium systems.", nullptr));
#endif // QT_CONFIG(tooltip)
        sphericMirrorCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Spheric mirror distortion", nullptr));
#if QT_CONFIG(tooltip)
        autoZoomResetsDirectionCheckbox->setToolTip(QCoreApplication::translate("configurationDialogForm", "When enabled, the \"auto zoom out\" key will also set the initial viewing direction", nullptr));
#endif // QT_CONFIG(tooltip)
        autoZoomResetsDirectionCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Auto-direction at zoom out", nullptr));
#if QT_CONFIG(tooltip)
        focusOnDaySpinnerCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Force date/time tab and focus on day input when activating date panel", nullptr));
#endif // QT_CONFIG(tooltip)
        focusOnDaySpinnerCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Set keyboard focus to day input", nullptr));
#if QT_CONFIG(tooltip)
        enableMouseZoomingCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Allow mouse to zoom (mousewheel)", nullptr));
#endif // QT_CONFIG(tooltip)
        enableMouseZoomingCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Enable mouse zooming", nullptr));
#if QT_CONFIG(tooltip)
        indicationMountModeCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Flash a short message when toggling mount mode.", nullptr));
#endif // QT_CONFIG(tooltip)
        indicationMountModeCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Indication for mount mode", nullptr));
#if QT_CONFIG(tooltip)
        overwriteTextColorButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Info text color for overwrite", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        overwriteTextColorCheckBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Set one color for text in info panel for all objects", nullptr));
#endif // QT_CONFIG(tooltip)
        overwriteTextColorCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Overwrite text color", nullptr));
        label_threads->setText(QCoreApplication::translate("configurationDialogForm", "Additional threads for solar system", nullptr));
#if QT_CONFIG(tooltip)
        solarSystemThreadNumberSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "A few additional threads may improve speed with many solar system objects. Observe what works best on your multicore system.", nullptr));
#endif // QT_CONFIG(tooltip)
        fontSizeLabel->setText(QCoreApplication::translate("configurationDialogForm", "Font size: Screen", nullptr));
#if QT_CONFIG(tooltip)
        screenFontSizeSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Base font size for on-screen text", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        guiFontSizeLabel->setToolTip(QCoreApplication::translate("configurationDialogForm", "Graphical user interface", nullptr));
#endif // QT_CONFIG(tooltip)
        guiFontSizeLabel->setText(QCoreApplication::translate("configurationDialogForm", "GUI", "abbreviation"));
#if QT_CONFIG(tooltip)
        guiFontSizeSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Base font size for dialogs", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fontWritingSystemComboBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Pre-select fonts for a particular writing system", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fontComboBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Application font", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        fontSaveToolButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Store font settings", nullptr));
#endif // QT_CONFIG(tooltip)
        fontSaveToolButton->setText(QCoreApplication::translate("configurationDialogForm", "Save", nullptr));
        label_4->setText(QCoreApplication::translate("configurationDialogForm", "Screen button scale:", nullptr));
        groupBox_Screenshots->setTitle(QCoreApplication::translate("configurationDialogForm", "Screenshots", nullptr));
        label->setText(QCoreApplication::translate("configurationDialogForm", "Screenshot Directory", nullptr));
        screenshotBrowseButton->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonConfigureScreenshotsDialog->setToolTip(QCoreApplication::translate("configurationDialogForm", "Rules for screenshot file naming", nullptr));
#endif // QT_CONFIG(tooltip)
        labelFileFormat->setText(QCoreApplication::translate("configurationDialogForm", "File format", nullptr));
        invertScreenShotColorsCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Invert colors", nullptr));
        useCustomScreenshotSizeCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Custom size", nullptr));
        label_3->setText(QCoreApplication::translate("configurationDialogForm", "dpi", nullptr));
#if QT_CONFIG(tooltip)
        dpiSpinBox->setToolTip(QCoreApplication::translate("configurationDialogForm", "Dots per Inch (for printing size computation in image metadata). Native print size in inches is then pixelSize/dpi.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_Narration->setTitle(QCoreApplication::translate("configurationDialogForm", "Speech Output", nullptr));
        label_TestText->setText(QCoreApplication::translate("configurationDialogForm", "Test text:", nullptr));
        label_engine->setText(QCoreApplication::translate("configurationDialogForm", "Speech Engine:", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_SpeechSay->setToolTip(QCoreApplication::translate("configurationDialogForm", "Emit speech synthesis of text from text box", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_SpeechSay->setText(QCoreApplication::translate("configurationDialogForm", "Say", nullptr));
#if QT_CONFIG(tooltip)
        pushButton_SpeechStop->setToolTip(QCoreApplication::translate("configurationDialogForm", "Stop a running speech", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButton_SpeechStop->setText(QCoreApplication::translate("configurationDialogForm", "Stop", nullptr));
        label_Voice->setText(QCoreApplication::translate("configurationDialogForm", "Voice:", nullptr));
#if QT_CONFIG(tooltip)
        comboBox_Voice->setToolTip(QCoreApplication::translate("configurationDialogForm", "Voice in program language.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_Pitch->setText(QCoreApplication::translate("configurationDialogForm", "Pitch:", nullptr));
        label_Rate->setText(QCoreApplication::translate("configurationDialogForm", "Rate:", nullptr));
        label_Volume->setText(QCoreApplication::translate("configurationDialogForm", "Volume:", nullptr));
        groupBox_8->setTitle(QCoreApplication::translate("configurationDialogForm", "Options", nullptr));
        scriptStatusLabel->setText(QString());
        closeWindowAtScriptRunCheckbox->setText(QCoreApplication::translate("configurationDialogForm", "Close window when script runs", nullptr));
#if QT_CONFIG(tooltip)
        runScriptButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Run the selected script", nullptr));
#endif // QT_CONFIG(tooltip)
        runScriptButton->setText(QString());
#if QT_CONFIG(tooltip)
        stopScriptButton->setToolTip(QCoreApplication::translate("configurationDialogForm", "Stop a running script", nullptr));
#endif // QT_CONFIG(tooltip)
        stopScriptButton->setText(QString());
        pluginsGroupBox->setTitle(QCoreApplication::translate("configurationDialogForm", "Options", nullptr));
        pluginLoadAtStartupCheckBox->setText(QCoreApplication::translate("configurationDialogForm", "Load at startup", nullptr));
        pluginConfigureButton->setText(QCoreApplication::translate("configurationDialogForm", "configure", nullptr));
        (void)configurationDialogForm;
    } // retranslateUi

};

namespace Ui {
    class configurationDialogForm: public Ui_configurationDialogForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGURATIONDIALOG_H
